# APIs for Windows 32-bit gdi32 library.
# Format:  rettype, retname, callconv, exactname, arglist(type, name)
#          arglist type is one of ['int', 'void *']
#          arglist name is one of [None, 'funcptr', 'obj', 'ptr']

api_defs = {
    'gdi32.main_entry':( 'int', None, 'stdcall', 'gdi32.main_entry', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.abortdoc':( 'int', None, 'stdcall', 'gdi32.AbortDoc', (('int', None),) ),
    'gdi32.abortpath':( 'int', None, 'stdcall', 'gdi32.AbortPath', (('int', None),) ),
    'gdi32.addfontmemresourceex':( 'int', None, 'stdcall', 'gdi32.AddFontMemResourceEx', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.addfontresourcea':( 'int', None, 'stdcall', 'gdi32.AddFontResourceA', (('int', None),) ),
    'gdi32.addfontresourceexa':( 'int', None, 'stdcall', 'gdi32.AddFontResourceExA', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.addfontresourceexw':( 'int', None, 'stdcall', 'gdi32.AddFontResourceExW', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'gdi32.addfontresourcetracking':( 'int', None, 'stdcall', 'gdi32.AddFontResourceTracking', (('int', None), ('int', None)) ),
    'gdi32.addfontresourcew':( 'int', None, 'stdcall', 'gdi32.AddFontResourceW', (('void *', 'ptr'),) ),
    'gdi32.anglearc':( 'int', None, 'stdcall', 'gdi32.AngleArc', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.animatepalette':( 'int', None, 'stdcall', 'gdi32.AnimatePalette', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.anylinkedfonts':( 'int', None, 'cdecl', 'gdi32.AnyLinkedFonts', () ),
    'gdi32.arc':( 'int', None, 'stdcall', 'gdi32.Arc', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.arcto':( 'int', None, 'stdcall', 'gdi32.ArcTo', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.brushobj_hgetcolortransform':( 'int', None, 'stdcall', 'gdi32.BRUSHOBJ_hGetColorTransform', (('int', None),) ),
    'gdi32.brushobj_pvallocrbrush':( 'int', None, 'stdcall', 'gdi32.BRUSHOBJ_pvAllocRbrush', (('int', None), ('int', None)) ),
    'gdi32.brushobj_pvgetrbrush':( 'int', None, 'stdcall', 'gdi32.BRUSHOBJ_pvGetRbrush', (('int', None),) ),
    'gdi32.brushobj_ulgetbrushcolor':( 'int', None, 'stdcall', 'gdi32.BRUSHOBJ_ulGetBrushColor', (('int', None),) ),
    'gdi32.beginpath':( 'int', None, 'stdcall', 'gdi32.BeginPath', (('int', None),) ),
    'gdi32.bitblt':( 'int', None, 'stdcall', 'gdi32.BitBlt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.clipobj_benum':( 'int', None, 'stdcall', 'gdi32.CLIPOBJ_bEnum', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.clipobj_cenumstart':( 'int', None, 'stdcall', 'gdi32.CLIPOBJ_cEnumStart', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.clipobj_ppogetpath':( 'int', None, 'stdcall', 'gdi32.CLIPOBJ_ppoGetPath', (('int', None),) ),
    'gdi32.canceldc':( 'int', None, 'stdcall', 'gdi32.CancelDC', (('int', None),) ),
    'gdi32.checkcolorsingamut':( 'int', None, 'stdcall', 'gdi32.CheckColorsInGamut', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.choosepixelformat':( 'int', None, 'stdcall', 'gdi32.ChoosePixelFormat', ( ('int', None), ('void *', 'ptr')) ),
    'gdi32.chord':( 'int', None, 'stdcall', 'gdi32.Chord', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.clearbitmapattributes':( 'int', None, 'stdcall', 'gdi32.ClearBitmapAttributes', (('int', None), ('int', None)) ),
    'gdi32.clearbrushattributes':( 'int', None, 'stdcall', 'gdi32.ClearBrushAttributes', (('int', None), ('int', None)) ),
    'gdi32.closeenhmetafile':( 'int', None, 'stdcall', 'gdi32.CloseEnhMetaFile', (('int', None),) ),
    'gdi32.closefigure':( 'int', None, 'stdcall', 'gdi32.CloseFigure', (('int', None),) ),
    'gdi32.closemetafile':( 'int', None, 'stdcall', 'gdi32.CloseMetaFile', (('int', None),) ),
    'gdi32.colorcorrectpalette':( 'int', None, 'stdcall', 'gdi32.ColorCorrectPalette', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.colormatchtotarget':( 'int', None, 'stdcall', 'gdi32.ColorMatchToTarget', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.combinergn':( 'int', None, 'stdcall', 'gdi32.CombineRgn', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.combinetransform':( 'int', None, 'stdcall', 'gdi32.CombineTransform', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.copyenhmetafilea':( 'int', None, 'stdcall', 'gdi32.CopyEnhMetaFileA', (('int', None), ('int', None)) ),
    'gdi32.copyenhmetafilew':( 'int', None, 'stdcall', 'gdi32.CopyEnhMetaFileW', (('int', None), ('StringW', None)) ),
    'gdi32.copymetafilea':( 'int', None, 'stdcall', 'gdi32.CopyMetaFileA', (('int', None), ('int', None)) ),
    'gdi32.copymetafilew':( 'int', None, 'stdcall', 'gdi32.CopyMetaFileW', (('int', None), ('void *', 'ptr')) ),
    'gdi32.createbitmap':( 'int', None, 'stdcall', 'gdi32.CreateBitmap', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createbitmapindirect':( 'int', None, 'stdcall', 'gdi32.CreateBitmapIndirect', (('void *', 'ptr'),) ),
    'gdi32.createbrushindirect':( 'int', None, 'stdcall', 'gdi32.CreateBrushIndirect', (('void *', 'ptr'),) ),
    'gdi32.createcolorspacea':( 'int', None, 'stdcall', 'gdi32.CreateColorSpaceA', (('int', None),) ),
    'gdi32.createcolorspacew':( 'int', None, 'stdcall', 'gdi32.CreateColorSpaceW', (('void *', 'ptr'),) ),
    'gdi32.createcompatiblebitmap':( 'int', None, 'stdcall', 'gdi32.CreateCompatibleBitmap', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.createcompatibledc':( 'int', None, 'stdcall', 'gdi32.CreateCompatibleDC', (('int', None),) ),
    'gdi32.createdca':( 'int', None, 'stdcall', 'gdi32.CreateDCA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createdcw':( 'int', None, 'stdcall', 'gdi32.CreateDCW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createdibpatternbrush':( 'int', None, 'stdcall', 'gdi32.CreateDIBPatternBrush', ( ('int', None), ('int', None)) ),
    'gdi32.createdibpatternbrushpt':( 'int', None, 'stdcall', 'gdi32.CreateDIBPatternBrushPt', (('int', None), ('int', None)) ),
    'gdi32.createdibsection':( 'int', None, 'stdcall', 'gdi32.CreateDIBSection', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'gdi32.createdibitmap':( 'int', None, 'stdcall', 'gdi32.CreateDIBitmap', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.creatediscardablebitmap':( 'int', None, 'stdcall', 'gdi32.CreateDiscardableBitmap', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.createellipticrgn':( 'int', None, 'stdcall', 'gdi32.CreateEllipticRgn', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createellipticrgnindirect':( 'int', None, 'stdcall', 'gdi32.CreateEllipticRgnIndirect', (('int', None),) ),
    'gdi32.createenhmetafilea':( 'int', None, 'stdcall', 'gdi32.CreateEnhMetaFileA', (('int', None), ('int', None), ('void *', 'obj'), ('int', None)) ),
    'gdi32.createenhmetafilew':( 'int', None, 'stdcall', 'gdi32.CreateEnhMetaFileW', (('int', None), ('void *', 'ptr'), ('void *', 'obj'), ('int', None)) ),
    'gdi32.createfonta':( 'int', None, 'stdcall', 'gdi32.CreateFontA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createfontindirecta':( 'int', None, 'stdcall', 'gdi32.CreateFontIndirectA', (('void *', 'ptr'),) ),
    'gdi32.createfontindirectexa':( 'int', None, 'stdcall', 'gdi32.CreateFontIndirectExA', (('int', None),) ),
    'gdi32.createfontindirectexw':( 'int', None, 'stdcall', 'gdi32.CreateFontIndirectExW', (('void *', 'ptr'),) ),
    'gdi32.createfontindirectw':( 'int', None, 'stdcall', 'gdi32.CreateFontIndirectW', (('void *', 'ptr'),) ),
    'gdi32.createfontw':( 'int', None, 'stdcall', 'gdi32.CreateFontW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createhalftonepalette':( 'int', None, 'stdcall', 'gdi32.CreateHalftonePalette', (('int', None),) ),
    'gdi32.createhatchbrush':( 'int', None, 'stdcall', 'gdi32.CreateHatchBrush', (('int', None), ('int', None)) ),
    'gdi32.createica':( 'int', None, 'stdcall', 'gdi32.CreateICA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createicw':( 'int', None, 'stdcall', 'gdi32.CreateICW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createmetafilea':( 'int', None, 'stdcall', 'gdi32.CreateMetaFileA', (('int', None),) ),
    'gdi32.createmetafilew':( 'int', None, 'stdcall', 'gdi32.CreateMetaFileW', (('int', None),) ),
    'gdi32.createpalette':( 'int', None, 'stdcall', 'gdi32.CreatePalette', (('int', None),) ),
    'gdi32.createpatternbrush':( 'int', None, 'stdcall', 'gdi32.CreatePatternBrush', (('int', None),) ),
    'gdi32.createpen':( 'int', None, 'stdcall', 'gdi32.CreatePen', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.createpenindirect':( 'int', None, 'stdcall', 'gdi32.CreatePenIndirect', (('void *', 'ptr'),) ),
    'gdi32.createpolypolygonrgn':( 'int', None, 'stdcall', 'gdi32.CreatePolyPolygonRgn', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createpolygonrgn':( 'int', None, 'stdcall', 'gdi32.CreatePolygonRgn', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.createrectrgn':( 'int', None, 'stdcall', 'gdi32.CreateRectRgn', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createrectrgnindirect':( 'int', None, 'stdcall', 'gdi32.CreateRectRgnIndirect', (('int', None),) ),
    'gdi32.createroundrectrgn':( 'int', None, 'stdcall', 'gdi32.CreateRoundRectRgn', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createscalablefontresourcea':( 'int', None, 'stdcall', 'gdi32.CreateScalableFontResourceA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.createscalablefontresourcew':( 'int', None, 'stdcall', 'gdi32.CreateScalableFontResourceW', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'gdi32.createsolidbrush':( 'int', None, 'stdcall', 'gdi32.CreateSolidBrush', (('int', None),) ),
    'gdi32.dptolp':( 'int', None, 'stdcall', 'gdi32.DPtoLP', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry0':( 'int', None, 'stdcall', 'gdi32.DdEntry0', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry1':( 'int', None, 'stdcall', 'gdi32.DdEntry1', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry10':( 'int', None, 'stdcall', 'gdi32.DdEntry10', (('int', None), ('int', None)) ),
    'gdi32.ddentry11':( 'int', None, 'stdcall', 'gdi32.DdEntry11', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry12':( 'int', None, 'stdcall', 'gdi32.DdEntry12', (('int', None), ('int', None)) ),
    'gdi32.ddentry13':( 'int', None, 'stdcall', 'gdi32.DdEntry13', (('int', None), ('int', None)) ),
    'gdi32.ddentry14':( 'int', None, 'stdcall', 'gdi32.DdEntry14', (('int', None), ('int', None)) ),
    'gdi32.ddentry15':( 'int', None, 'stdcall', 'gdi32.DdEntry15', (('int', None),) ),
    'gdi32.ddentry16':( 'int', None, 'stdcall', 'gdi32.DdEntry16', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry17':( 'int', None, 'stdcall', 'gdi32.DdEntry17', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'gdi32.ddentry18':( 'int', None, 'stdcall', 'gdi32.DdEntry18', (('int', None), ('int', None)) ),
    'gdi32.ddentry19':( 'int', None, 'stdcall', 'gdi32.DdEntry19', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.ddentry2':( 'int', None, 'stdcall', 'gdi32.DdEntry2', (('int', None),) ),
    'gdi32.ddentry20':( 'int', None, 'stdcall', 'gdi32.DdEntry20', (('int', None),) ),
    'gdi32.ddentry21':( 'int', None, 'stdcall', 'gdi32.DdEntry21', (('int', None),) ),
    'gdi32.ddentry22':( 'int', None, 'stdcall', 'gdi32.DdEntry22', (('int', None), ('int', None)) ),
    'gdi32.ddentry23':( 'int', None, 'stdcall', 'gdi32.DdEntry23', (('int', None), ('int', None)) ),
    'gdi32.ddentry24':( 'int', None, 'stdcall', 'gdi32.DdEntry24', (('int', None),) ),
    'gdi32.ddentry25':( 'int', None, 'stdcall', 'gdi32.DdEntry25', (('int', None), ('int', None)) ),
    'gdi32.ddentry26':( 'int', None, 'stdcall', 'gdi32.DdEntry26', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry27':( 'int', None, 'stdcall', 'gdi32.DdEntry27', (('int', None), ('int', None)) ),
    'gdi32.ddentry28':( 'int', None, 'stdcall', 'gdi32.DdEntry28', (('int', None), ('int', None)) ),
    'gdi32.ddentry29':( 'int', None, 'stdcall', 'gdi32.DdEntry29', (('int', None), ('int', None)) ),
    'gdi32.ddentry3':( 'int', None, 'stdcall', 'gdi32.DdEntry3', (('int', None),) ),
    'gdi32.ddentry30':( 'int', None, 'stdcall', 'gdi32.DdEntry30', (('int', None), ('int', None)) ),
    'gdi32.ddentry31':( 'int', None, 'stdcall', 'gdi32.DdEntry31', (('int', None), ('void *', 'ptr')) ),
    'gdi32.ddentry32':( 'int', None, 'stdcall', 'gdi32.DdEntry32', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry33':( 'int', None, 'stdcall', 'gdi32.DdEntry33', (('int', None), ('int', None)) ),
    'gdi32.ddentry34':( 'int', None, 'stdcall', 'gdi32.DdEntry34', (('int', None), ('int', None)) ),
    'gdi32.ddentry35':( 'int', None, 'stdcall', 'gdi32.DdEntry35', (('int', None), ('int', None)) ),
    'gdi32.ddentry36':( 'int', None, 'stdcall', 'gdi32.DdEntry36', (('int', None), ('int', None)) ),
    'gdi32.ddentry37':( 'int', None, 'stdcall', 'gdi32.DdEntry37', (('int', None), ('int', None)) ),
    'gdi32.ddentry38':( 'int', None, 'stdcall', 'gdi32.DdEntry38', (('int', None), ('int', None)) ),
    'gdi32.ddentry39':( 'int', None, 'stdcall', 'gdi32.DdEntry39', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry4':( 'int', None, 'stdcall', 'gdi32.DdEntry4', (('int', None),) ),
    'gdi32.ddentry40':( 'int', None, 'stdcall', 'gdi32.DdEntry40', (('int', None), ('int', None)) ),
    'gdi32.ddentry41':( 'int', None, 'stdcall', 'gdi32.DdEntry41', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.ddentry42':( 'int', None, 'stdcall', 'gdi32.DdEntry42', (('int', None), ('int', None)) ),
    'gdi32.ddentry43':( 'int', None, 'stdcall', 'gdi32.DdEntry43', (('int', None), ('int', None)) ),
    'gdi32.ddentry44':( 'int', None, 'stdcall', 'gdi32.DdEntry44', (('int', None),) ),
    'gdi32.ddentry45':( 'int', None, 'stdcall', 'gdi32.DdEntry45', (('int', None), ('int', None)) ),
    'gdi32.ddentry46':( 'int', None, 'stdcall', 'gdi32.DdEntry46', (('int', None), ('int', None)) ),
    'gdi32.ddentry47':( 'int', None, 'stdcall', 'gdi32.DdEntry47', (('int', None), ('int', None)) ),
    'gdi32.ddentry48':( 'int', None, 'stdcall', 'gdi32.DdEntry48', (('int', None), ('int', None)) ),
    'gdi32.ddentry49':( 'int', None, 'stdcall', 'gdi32.DdEntry49', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry5':( 'int', None, 'stdcall', 'gdi32.DdEntry5', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry50':( 'int', None, 'stdcall', 'gdi32.DdEntry50', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry51':( 'int', None, 'stdcall', 'gdi32.DdEntry51', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry52':( 'int', None, 'stdcall', 'gdi32.DdEntry52', (('int', None), ('int', None)) ),
    'gdi32.ddentry53':( 'int', None, 'stdcall', 'gdi32.DdEntry53', (('int', None), ('int', None)) ),
    'gdi32.ddentry54':( 'int', None, 'stdcall', 'gdi32.DdEntry54', (('int', None), ('int', None)) ),
    'gdi32.ddentry55':( 'int', None, 'stdcall', 'gdi32.DdEntry55', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry56':( 'int', None, 'stdcall', 'gdi32.DdEntry56', (('int', None), ('int', None)) ),
    'gdi32.ddentry6':( 'int', None, 'stdcall', 'gdi32.DdEntry6', (('int', None),) ),
    'gdi32.ddentry7':( 'int', None, 'stdcall', 'gdi32.DdEntry7', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry8':( 'int', None, 'stdcall', 'gdi32.DdEntry8', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.ddentry9':( 'int', None, 'stdcall', 'gdi32.DdEntry9', (('int', None), ('int', None)) ),
    'gdi32.deletecolorspace':( 'int', None, 'stdcall', 'gdi32.DeleteColorSpace', (('int', None),) ),
    'gdi32.deletedc':( 'int', None, 'stdcall', 'gdi32.DeleteDC', (('int', None),) ),
    'gdi32.deleteenhmetafile':( 'int', None, 'stdcall', 'gdi32.DeleteEnhMetaFile', (('int', None),) ),
    'gdi32.deletemetafile':( 'int', None, 'stdcall', 'gdi32.DeleteMetaFile', (('int', None),) ),
    'gdi32.deleteobject':( 'int', None, 'stdcall', 'gdi32.DeleteObject', (('int', None),) ),
    'gdi32.describepixelformat':( 'int', None, 'stdcall', 'gdi32.DescribePixelFormat', ( ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.devicecapabilitiesexa':( 'int', None, 'stdcall', 'gdi32.DeviceCapabilitiesExA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.devicecapabilitiesexw':( 'int', None, 'stdcall', 'gdi32.DeviceCapabilitiesExW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.drawescape':( 'int', None, 'stdcall', 'gdi32.DrawEscape', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.ellipse':( 'int', None, 'stdcall', 'gdi32.Ellipse', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.enableeudc':( 'int', None, 'stdcall', 'gdi32.EnableEUDC', (('int', None),) ),
    'gdi32.enddoc':( 'int', None, 'stdcall', 'gdi32.EndDoc', (('int', None),) ),
    'gdi32.endformpage':( 'int', None, 'stdcall', 'gdi32.EndFormPage', (('int', None),) ),
    'gdi32.endpage':( 'int', None, 'stdcall', 'gdi32.EndPage', (('int', None),) ),
    'gdi32.endpath':( 'int', None, 'stdcall', 'gdi32.EndPath', (('int', None),) ),
    'gdi32.engacquiresemaphore':( 'int', None, 'cdecl', 'gdi32.EngAcquireSemaphore', () ),
    'gdi32.engalphablend':( 'int', None, 'stdcall', 'gdi32.EngAlphaBlend', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engassociatesurface':( 'int', None, 'stdcall', 'gdi32.EngAssociateSurface', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.engbitblt':( 'int', None, 'stdcall', 'gdi32.EngBitBlt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engcheckabort':( 'int', None, 'stdcall', 'gdi32.EngCheckAbort', (('int', None),) ),
    'gdi32.engcomputeglyphset':( 'int', None, 'stdcall', 'gdi32.EngComputeGlyphSet', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.engcopybits':( 'int', None, 'stdcall', 'gdi32.EngCopyBits', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engcreatebitmap':( 'int', None, 'stdcall', 'gdi32.EngCreateBitmap', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engcreateclip':( 'int', None, 'cdecl', 'gdi32.EngCreateClip', () ),
    'gdi32.engcreatedevicebitmap':( 'int', None, 'stdcall', 'gdi32.EngCreateDeviceBitmap', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engcreatedevicesurface':( 'int', None, 'stdcall', 'gdi32.EngCreateDeviceSurface', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engcreatepalette':( 'int', None, 'stdcall', 'gdi32.EngCreatePalette', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engcreatesemaphore':( 'int', None, 'cdecl', 'gdi32.EngCreateSemaphore', () ),
    'gdi32.engdeleteclip':( 'int', None, 'stdcall', 'gdi32.EngDeleteClip', (('int', None),) ),
    'gdi32.engdeletepalette':( 'int', None, 'stdcall', 'gdi32.EngDeletePalette', (('int', None),) ),
    'gdi32.engdeletepath':( 'int', None, 'stdcall', 'gdi32.EngDeletePath', (('int', None),) ),
    'gdi32.engdeletesemaphore':( 'int', None, 'stdcall', 'gdi32.EngDeleteSemaphore', (('void *', 'ptr'),) ),
    'gdi32.engdeletesurface':( 'int', None, 'stdcall', 'gdi32.EngDeleteSurface', (('int', None),) ),
    'gdi32.engerasesurface':( 'int', None, 'stdcall', 'gdi32.EngEraseSurface', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.engfillpath':( 'int', None, 'stdcall', 'gdi32.EngFillPath', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engfindresource':( 'int', None, 'stdcall', 'gdi32.EngFindResource', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engfreemodule':( 'int', None, 'cdecl', 'gdi32.EngFreeModule', () ),
    'gdi32.enggetcurrentcodepage':( 'int', None, 'stdcall', 'gdi32.EngGetCurrentCodePage', (('int', None), ('int', None)) ),
    'gdi32.enggetdrivername':( 'int', None, 'stdcall', 'gdi32.EngGetDriverName', (('int', None),) ),
    'gdi32.enggetprinterdatafilename':( 'int', None, 'stdcall', 'gdi32.EngGetPrinterDataFileName', (('int', None),) ),
    'gdi32.enggradientfill':( 'int', None, 'stdcall', 'gdi32.EngGradientFill', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.englineto':( 'int', None, 'stdcall', 'gdi32.EngLineTo', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engloadmodule':( 'int', None, 'stdcall', 'gdi32.EngLoadModule', (('int', None),) ),
    'gdi32.englocksurface':( 'int', None, 'stdcall', 'gdi32.EngLockSurface', (('int', None),) ),
    'gdi32.engmarkbandingsurface':( 'int', None, 'stdcall', 'gdi32.EngMarkBandingSurface', (('int', None),) ),
    'gdi32.engmultibytetounicoden':( 'int', None, 'cdecl', 'gdi32.EngMultiByteToUnicodeN', () ),
    'gdi32.engmultibytetowidechar':( 'int', None, 'stdcall', 'gdi32.EngMultiByteToWideChar', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engpaint':( 'int', None, 'stdcall', 'gdi32.EngPaint', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engplgblt':( 'int', None, 'stdcall', 'gdi32.EngPlgBlt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engqueryemfinfo':( 'int', None, 'stdcall', 'gdi32.EngQueryEMFInfo', (('int', None), ('int', None)) ),
    'gdi32.engquerylocaltime':( 'int', None, 'stdcall', 'gdi32.EngQueryLocalTime', (('int', None),) ),
    'gdi32.engreleasesemaphore':( 'int', None, 'cdecl', 'gdi32.EngReleaseSemaphore', () ),
    'gdi32.engstretchblt':( 'int', None, 'stdcall', 'gdi32.EngStretchBlt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engstretchbltrop':( 'int', None, 'stdcall', 'gdi32.EngStretchBltROP', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engstrokeandfillpath':( 'int', None, 'stdcall', 'gdi32.EngStrokeAndFillPath', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engstrokepath':( 'int', None, 'stdcall', 'gdi32.EngStrokePath', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engtextout':( 'int', None, 'stdcall', 'gdi32.EngTextOut', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engtransparentblt':( 'int', None, 'stdcall', 'gdi32.EngTransparentBlt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.engunicodetomultibyten':( 'int', None, 'cdecl', 'gdi32.EngUnicodeToMultiByteN', () ),
    'gdi32.engunlocksurface':( 'int', None, 'stdcall', 'gdi32.EngUnlockSurface', (('int', None),) ),
    'gdi32.engwidechartomultibyte':( 'int', None, 'stdcall', 'gdi32.EngWideCharToMultiByte', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.enumenhmetafile':( 'int', None, 'stdcall', 'gdi32.EnumEnhMetaFile', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None), ('int', None)) ),
    'gdi32.enumfontfamiliesa':( 'int', None, 'stdcall', 'gdi32.EnumFontFamiliesA', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'gdi32.enumfontfamiliesexa':( 'int', None, 'stdcall', 'gdi32.EnumFontFamiliesExA', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None), ('int', None)) ),
    'gdi32.enumfontfamiliesexw':( 'int', None, 'stdcall', 'gdi32.EnumFontFamiliesExW', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None), ('int', None)) ),
    'gdi32.enumfontfamiliesw':( 'int', None, 'stdcall', 'gdi32.EnumFontFamiliesW', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'gdi32.enumfontsa':( 'int', None, 'stdcall', 'gdi32.EnumFontsA', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'gdi32.enumfontsw':( 'int', None, 'stdcall', 'gdi32.EnumFontsW', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'gdi32.enumicmprofilesa':( 'int', None, 'stdcall', 'gdi32.EnumICMProfilesA', (('int', None), ('void *', 'funcptr'), ('void *', 'ptr')) ),
    'gdi32.enumicmprofilesw':( 'int', None, 'stdcall', 'gdi32.EnumICMProfilesW', (('int', None), ('void *', 'funcptr'), ('void *', 'ptr')) ),
    'gdi32.enummetafile':( 'int', None, 'stdcall', 'gdi32.EnumMetaFile', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'gdi32.enumobjects':( 'int', None, 'stdcall', 'gdi32.EnumObjects', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'gdi32.equalrgn':( 'int', None, 'stdcall', 'gdi32.EqualRgn', (('int', None), ('int', None)) ),
    'gdi32.escape':( 'int', None, 'stdcall', 'gdi32.Escape', (('int', None), ('int', None), ('DWORD', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'gdi32.eudcloadlinkw':( 'int', None, 'stdcall', 'gdi32.EudcLoadLinkW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.eudcunloadlinkw':( 'int', None, 'stdcall', 'gdi32.EudcUnloadLinkW', (('int', None), ('int', None)) ),
    'gdi32.excludecliprect':( 'int', None, 'stdcall', 'gdi32.ExcludeClipRect', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.extcreatepen':( 'int', None, 'stdcall', 'gdi32.ExtCreatePen', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'gdi32.extcreateregion':( 'int', None, 'stdcall', 'gdi32.ExtCreateRegion', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.extescape':( 'int', None, 'stdcall', 'gdi32.ExtEscape', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'gdi32.extfloodfill':( 'int', None, 'stdcall', 'gdi32.ExtFloodFill', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.extselectcliprgn':( 'int', None, 'stdcall', 'gdi32.ExtSelectClipRgn', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.exttextouta':( 'int', None, 'stdcall', 'gdi32.ExtTextOutA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('DWORD', None), ('int', None)) ),
    'gdi32.exttextoutw':( 'int', None, 'stdcall', 'gdi32.ExtTextOutW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'gdi32.fontobj_cgetallglyphhandles':( 'int', None, 'stdcall', 'gdi32.FONTOBJ_cGetAllGlyphHandles', (('int', None), ('int', None)) ),
    'gdi32.fontobj_cgetglyphs':( 'int', None, 'stdcall', 'gdi32.FONTOBJ_cGetGlyphs', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.fontobj_pqueryglyphattrs':( 'int', None, 'stdcall', 'gdi32.FONTOBJ_pQueryGlyphAttrs', (('int', None), ('int', None)) ),
    'gdi32.fontobj_pfdg':( 'int', None, 'stdcall', 'gdi32.FONTOBJ_pfdg', (('int', None),) ),
    'gdi32.fontobj_pifi':( 'int', None, 'stdcall', 'gdi32.FONTOBJ_pifi', (('int', None),) ),
    'gdi32.fontobj_pvtruetypefontfile':( 'int', None, 'stdcall', 'gdi32.FONTOBJ_pvTrueTypeFontFile', (('int', None), ('int', None)) ),
    'gdi32.fontobj_pxogetxform':( 'int', None, 'stdcall', 'gdi32.FONTOBJ_pxoGetXform', (('int', None),) ),
    'gdi32.fontobj_vgetinfo':( 'int', None, 'stdcall', 'gdi32.FONTOBJ_vGetInfo', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.fillpath':( 'int', None, 'stdcall', 'gdi32.FillPath', (('int', None),) ),
    'gdi32.fillrgn':( 'int', None, 'stdcall', 'gdi32.FillRgn', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.fixbrushorgex':( 'int', None, 'stdcall', 'gdi32.FixBrushOrgEx', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.flattenpath':( 'int', None, 'stdcall', 'gdi32.FlattenPath', (('int', None),) ),
    'gdi32.floodfill':( 'int', None, 'stdcall', 'gdi32.FloodFill', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.fontislinked':( 'int', None, 'stdcall', 'gdi32.FontIsLinked', (('int', None),) ),
    'gdi32.framergn':( 'int', None, 'stdcall', 'gdi32.FrameRgn', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdiaddfontresourcew':( 'int', None, 'stdcall', 'gdi32.GdiAddFontResourceW', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'gdi32.gdiaddglsbounds':( 'int', None, 'stdcall', 'gdi32.GdiAddGlsBounds', (('int', None), ('void *', 'ptr')) ),
    'gdi32.gdiaddglsrecord':( 'int', None, 'stdcall', 'gdi32.GdiAddGlsRecord', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdialphablend':( 'int', None, 'stdcall', 'gdi32.GdiAlphaBlend', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdiartificialdecrementdriver':( 'int', None, 'stdcall', 'gdi32.GdiArtificialDecrementDriver', (('int', None), ('int', None)) ),
    'gdi32.gdicleancachedc':( 'int', None, 'stdcall', 'gdi32.GdiCleanCacheDC', (('int', None),) ),
    'gdi32.gdicomment':( 'int', None, 'stdcall', 'gdi32.GdiComment', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.gdiconsoletextout':( 'int', None, 'stdcall', 'gdi32.GdiConsoleTextOut', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdiconvertandcheckdc':( 'int', None, 'stdcall', 'gdi32.GdiConvertAndCheckDC', (('int', None),) ),
    'gdi32.gdiconvertbitmap':( 'int', None, 'stdcall', 'gdi32.GdiConvertBitmap', (('int', None),) ),
    'gdi32.gdiconvertbitmapv5':( 'int', None, 'stdcall', 'gdi32.GdiConvertBitmapV5', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdiconvertbrush':( 'int', None, 'stdcall', 'gdi32.GdiConvertBrush', (('int', None),) ),
    'gdi32.gdiconvertdc':( 'int', None, 'stdcall', 'gdi32.GdiConvertDC', (('int', None),) ),
    'gdi32.gdiconvertenhmetafile':( 'int', None, 'stdcall', 'gdi32.GdiConvertEnhMetaFile', (('int', None),) ),
    'gdi32.gdiconvertfont':( 'int', None, 'stdcall', 'gdi32.GdiConvertFont', (('int', None),) ),
    'gdi32.gdiconvertmetafilepict':( 'int', None, 'stdcall', 'gdi32.GdiConvertMetaFilePict', (('int', None),) ),
    'gdi32.gdiconvertpalette':( 'int', None, 'stdcall', 'gdi32.GdiConvertPalette', (('int', None),) ),
    'gdi32.gdiconvertregion':( 'int', None, 'stdcall', 'gdi32.GdiConvertRegion', (('int', None),) ),
    'gdi32.gdiconverttodevmodew':( 'int', None, 'stdcall', 'gdi32.GdiConvertToDevmodeW', (('int', None),) ),
    'gdi32.gdicreatelocalenhmetafile':( 'int', None, 'stdcall', 'gdi32.GdiCreateLocalEnhMetaFile', (('int', None),) ),
    'gdi32.gdicreatelocalmetafilepict':( 'int', None, 'stdcall', 'gdi32.GdiCreateLocalMetaFilePict', (('int', None),) ),
    'gdi32.gdideletelocaldc':( 'int', None, 'stdcall', 'gdi32.GdiDeleteLocalDC', (('int', None),) ),
    'gdi32.gdideletespoolfilehandle':( 'int', None, 'stdcall', 'gdi32.GdiDeleteSpoolFileHandle', (('void *', 'ptr'),) ),
    'gdi32.gdidescribepixelformat':( 'int', None, 'stdcall', 'gdi32.GdiDescribePixelFormat', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdidllinitialize':( 'int', None, 'stdcall', 'gdi32.GdiDllInitialize', ( ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdidrawstream':( 'int', None, 'stdcall', 'gdi32.GdiDrawStream', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.gdienddocemf':( 'int', None, 'stdcall', 'gdi32.GdiEndDocEMF', (('int', None),) ),
    'gdi32.gdiendpageemf':( 'int', None, 'stdcall', 'gdi32.GdiEndPageEMF', (('int', None), ('int', None)) ),
    'gdi32.gdientry1':( 'int', None, 'stdcall', 'gdi32.GdiEntry1', (('int', None), ('int', None)) ),
    'gdi32.gdientry10':( 'int', None, 'stdcall', 'gdi32.GdiEntry10', (('int', None), ('int', None)) ),
    'gdi32.gdientry11':( 'int', None, 'stdcall', 'gdi32.GdiEntry11', (('int', None), ('int', None)) ),
    'gdi32.gdientry12':( 'int', None, 'stdcall', 'gdi32.GdiEntry12', (('int', None), ('int', None)) ),
    'gdi32.gdientry13':( 'int', None, 'cdecl', 'gdi32.GdiEntry13', () ),
    'gdi32.gdientry14':( 'int', None, 'stdcall', 'gdi32.GdiEntry14', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdientry15':( 'int', None, 'stdcall', 'gdi32.GdiEntry15', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdientry16':( 'int', None, 'stdcall', 'gdi32.GdiEntry16', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdientry2':( 'int', None, 'stdcall', 'gdi32.GdiEntry2', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdientry3':( 'int', None, 'stdcall', 'gdi32.GdiEntry3', (('int', None),) ),
    'gdi32.gdientry4':( 'int', None, 'stdcall', 'gdi32.GdiEntry4', (('int', None), ('int', None)) ),
    'gdi32.gdientry5':( 'int', None, 'stdcall', 'gdi32.GdiEntry5', (('int', None),) ),
    'gdi32.gdientry6':( 'int', None, 'stdcall', 'gdi32.GdiEntry6', (('int', None), ('int', None)) ),
    'gdi32.gdientry7':( 'int', None, 'stdcall', 'gdi32.GdiEntry7', (('int', None), ('int', None)) ),
    'gdi32.gdientry8':( 'int', None, 'stdcall', 'gdi32.GdiEntry8', (('int', None),) ),
    'gdi32.gdientry9':( 'int', None, 'stdcall', 'gdi32.GdiEntry9', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdifixuphandle':( 'int', None, 'stdcall', 'gdi32.GdiFixUpHandle', (('int', None),) ),
    'gdi32.gdiflush':( 'int', None, 'cdecl', 'gdi32.GdiFlush', () ),
    'gdi32.gdifullscreencontrol':( 'int', None, 'stdcall', 'gdi32.GdiFullscreenControl', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdigetbatchlimit':( 'int', None, 'cdecl', 'gdi32.GdiGetBatchLimit', () ),
    'gdi32.gdigetbitmapbitssize':( 'int', None, 'stdcall', 'gdi32.GdiGetBitmapBitsSize', (('int', None),) ),
    'gdi32.gdigetchardimensions':( 'int', None, 'stdcall', 'gdi32.GdiGetCharDimensions', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdigetcodepage':( 'int', None, 'stdcall', 'gdi32.GdiGetCodePage', (('int', None),) ),
    'gdi32.gdigetdc':( 'int', None, 'stdcall', 'gdi32.GdiGetDC', (('int', None),) ),
    'gdi32.gdigetdevmodeforpage':( 'int', None, 'stdcall', 'gdi32.GdiGetDevmodeForPage', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdigetlocalbrush':( 'int', None, 'stdcall', 'gdi32.GdiGetLocalBrush', (('int', None),) ),
    'gdi32.gdigetlocaldc':( 'int', None, 'stdcall', 'gdi32.GdiGetLocalDC', (('int', None),) ),
    'gdi32.gdigetlocalfont':( 'int', None, 'stdcall', 'gdi32.GdiGetLocalFont', (('int', None),) ),
    'gdi32.gdigetpagecount':( 'int', None, 'stdcall', 'gdi32.GdiGetPageCount', (('int', None),) ),
    'gdi32.gdigetpagehandle':( 'int', None, 'stdcall', 'gdi32.GdiGetPageHandle', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.gdigetspoolfilehandle':( 'int', None, 'stdcall', 'gdi32.GdiGetSpoolFileHandle', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdigetspoolmessage':( 'int', None, 'stdcall', 'gdi32.GdiGetSpoolMessage', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdigradientfill':( 'int', None, 'stdcall', 'gdi32.GdiGradientFill', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdiinitspool':( 'int', None, 'cdecl', 'gdi32.GdiInitSpool', () ),
    'gdi32.gdiinitializelanguagepack':( 'int', None, 'stdcall', 'gdi32.GdiInitializeLanguagePack', (('int', None),) ),
    'gdi32.gdiismetafiledc':( 'int', None, 'stdcall', 'gdi32.GdiIsMetaFileDC', (('int', None),) ),
    'gdi32.gdiismetaprintdc':( 'int', None, 'stdcall', 'gdi32.GdiIsMetaPrintDC', (('int', None),) ),
    'gdi32.gdiisplaymetafiledc':( 'int', None, 'stdcall', 'gdi32.GdiIsPlayMetafileDC', (('int', None),) ),
    'gdi32.gdiplaydcscript':( 'int', None, 'stdcall', 'gdi32.GdiPlayDCScript', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdiplayemf':( 'int', None, 'stdcall', 'gdi32.GdiPlayEMF', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdiplayjournal':( 'int', None, 'stdcall', 'gdi32.GdiPlayJournal', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdiplaypageemf':( 'int', None, 'stdcall', 'gdi32.GdiPlayPageEMF', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'gdi32.gdiplayprivatepageemf':( 'int', None, 'stdcall', 'gdi32.GdiPlayPrivatePageEMF', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdiplayscript':( 'int', None, 'stdcall', 'gdi32.GdiPlayScript', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdiprinterthunk':( 'int', None, 'stdcall', 'gdi32.GdiPrinterThunk', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdiprocesssetup':( 'int', None, 'cdecl', 'gdi32.GdiProcessSetup', () ),
    'gdi32.gdiqueryfonts':( 'int', None, 'stdcall', 'gdi32.GdiQueryFonts', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.gdiquerytable':( 'int', None, 'cdecl', 'gdi32.GdiQueryTable', () ),
    'gdi32.gdirealizationinfo':( 'int', None, 'stdcall', 'gdi32.GdiRealizationInfo', (('int', None), ('void *', 'ptr')) ),
    'gdi32.gdireleasedc':( 'int', None, 'stdcall', 'gdi32.GdiReleaseDC', (('int', None),) ),
    'gdi32.gdireleaselocaldc':( 'int', None, 'stdcall', 'gdi32.GdiReleaseLocalDC', (('int', None),) ),
    'gdi32.gdiresetdcemf':( 'int', None, 'stdcall', 'gdi32.GdiResetDCEMF', (('int', None), ('int', None)) ),
    'gdi32.gdisetattrs':( 'int', None, 'stdcall', 'gdi32.GdiSetAttrs', (('int', None),) ),
    'gdi32.gdisetbatchlimit':( 'int', None, 'stdcall', 'gdi32.GdiSetBatchLimit', (('int', None),) ),
    'gdi32.gdisetlasterror':( 'int', None, 'stdcall', 'gdi32.GdiSetLastError', (('int', None),) ),
    'gdi32.gdisetpixelformat':( 'int', None, 'stdcall', 'gdi32.GdiSetPixelFormat', (('int', None), ('int', None)) ),
    'gdi32.gdisetserverattr':( 'int', None, 'stdcall', 'gdi32.GdiSetServerAttr', (('int', None), ('int', None)) ),
    'gdi32.gdistartdocemf':( 'int', None, 'stdcall', 'gdi32.GdiStartDocEMF', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'gdi32.gdistartpageemf':( 'int', None, 'stdcall', 'gdi32.GdiStartPageEMF', (('int', None),) ),
    'gdi32.gdiswapbuffers':( 'int', None, 'stdcall', 'gdi32.GdiSwapBuffers', (('int', None),) ),
    'gdi32.gditransparentblt':( 'int', None, 'stdcall', 'gdi32.GdiTransparentBlt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gdivalidatehandle':( 'int', None, 'stdcall', 'gdi32.GdiValidateHandle', (('int', None),) ),
    'gdi32.getarcdirection':( 'int', None, 'stdcall', 'gdi32.GetArcDirection', (('int', None),) ),
    'gdi32.getaspectratiofilterex':( 'int', None, 'stdcall', 'gdi32.GetAspectRatioFilterEx', (('int', None), ('int', None)) ),
    'gdi32.getbitmapattributes':( 'int', None, 'stdcall', 'gdi32.GetBitmapAttributes', (('int', None),) ),
    'gdi32.getbitmapbits':( 'int', None, 'stdcall', 'gdi32.GetBitmapBits', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getbitmapdimensionex':( 'int', None, 'stdcall', 'gdi32.GetBitmapDimensionEx', (('int', None), ('int', None)) ),
    'gdi32.getbkcolor':( 'int', None, 'stdcall', 'gdi32.GetBkColor', (('int', None),) ),
    'gdi32.getbkmode':( 'int', None, 'stdcall', 'gdi32.GetBkMode', (('int', None),) ),
    'gdi32.getboundsrect':( 'int', None, 'stdcall', 'gdi32.GetBoundsRect', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getbrushattributes':( 'int', None, 'stdcall', 'gdi32.GetBrushAttributes', (('int', None),) ),
    'gdi32.getbrushorgex':( 'int', None, 'stdcall', 'gdi32.GetBrushOrgEx', (('int', None), ('void *', 'ptr')) ),
    'gdi32.getcharabcwidthsa':( 'int', None, 'stdcall', 'gdi32.GetCharABCWidthsA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharabcwidthsfloata':( 'int', None, 'stdcall', 'gdi32.GetCharABCWidthsFloatA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharabcwidthsfloatw':( 'int', None, 'stdcall', 'gdi32.GetCharABCWidthsFloatW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharabcwidthsi':( 'int', None, 'stdcall', 'gdi32.GetCharABCWidthsI', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharabcwidthsw':( 'int', None, 'stdcall', 'gdi32.GetCharABCWidthsW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharwidth32a':( 'int', None, 'stdcall', 'gdi32.GetCharWidth32A', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharwidth32w':( 'int', None, 'stdcall', 'gdi32.GetCharWidth32W', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharwidtha':( 'int', None, 'stdcall', 'gdi32.GetCharWidthA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharwidthfloata':( 'int', None, 'stdcall', 'gdi32.GetCharWidthFloatA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharwidthfloatw':( 'int', None, 'stdcall', 'gdi32.GetCharWidthFloatW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharwidthi':( 'int', None, 'stdcall', 'gdi32.GetCharWidthI', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.getcharwidthinfo':( 'int', None, 'stdcall', 'gdi32.GetCharWidthInfo', (('int', None), ('int', None)) ),
    'gdi32.getcharwidthw':( 'int', None, 'stdcall', 'gdi32.GetCharWidthW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharacterplacementa':( 'int', None, 'stdcall', 'gdi32.GetCharacterPlacementA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getcharacterplacementw':( 'int', None, 'stdcall', 'gdi32.GetCharacterPlacementW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getclipbox':( 'int', None, 'stdcall', 'gdi32.GetClipBox', (('int', None), ('void *', 'ptr')) ),
    'gdi32.getcliprgn':( 'int', None, 'stdcall', 'gdi32.GetClipRgn', (('int', None), ('int', None)) ),
    'gdi32.getcoloradjustment':( 'int', None, 'stdcall', 'gdi32.GetColorAdjustment', (('int', None), ('int', None)) ),
    'gdi32.getcolorspace':( 'int', None, 'stdcall', 'gdi32.GetColorSpace', (('int', None),) ),
    'gdi32.getcurrentobject':( 'int', None, 'stdcall', 'gdi32.GetCurrentObject', (('int', None), ('int', None)) ),
    'gdi32.getcurrentpositionex':( 'int', None, 'stdcall', 'gdi32.GetCurrentPositionEx', (('int', None), ('void *', 'ptr')) ),
    'gdi32.getdcbrushcolor':( 'int', None, 'stdcall', 'gdi32.GetDCBrushColor', (('int', None),) ),
    'gdi32.getdcorgex':( 'int', None, 'stdcall', 'gdi32.GetDCOrgEx', (('int', None), ('int', None)) ),
    'gdi32.getdcpencolor':( 'int', None, 'stdcall', 'gdi32.GetDCPenColor', (('int', None),) ),
    'gdi32.getdibcolortable':( 'int', None, 'stdcall', 'gdi32.GetDIBColorTable', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.getdibits':( 'int', None, 'stdcall', 'gdi32.GetDIBits', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.getdevicecaps':( 'int', None, 'stdcall', 'gdi32.GetDeviceCaps', (('int', None), ('int', None)) ),
    'gdi32.getdevicegammaramp':( 'int', None, 'stdcall', 'gdi32.GetDeviceGammaRamp', (('int', None), ('int', None)) ),
    'gdi32.getetm':( 'int', None, 'stdcall', 'gdi32.GetETM', (('int', None), ('void *', 'ptr')) ),
    'gdi32.geteudctimestamp':( 'int', None, 'cdecl', 'gdi32.GetEUDCTimeStamp', () ),
    'gdi32.geteudctimestampexw':( 'int', None, 'stdcall', 'gdi32.GetEUDCTimeStampExW', (('int', None),) ),
    'gdi32.getenhmetafilea':( 'int', None, 'stdcall', 'gdi32.GetEnhMetaFileA', (('int', None),) ),
    'gdi32.getenhmetafilebits':( 'int', None, 'stdcall', 'gdi32.GetEnhMetaFileBits', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getenhmetafiledescriptiona':( 'int', None, 'stdcall', 'gdi32.GetEnhMetaFileDescriptionA', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getenhmetafiledescriptionw':( 'int', None, 'stdcall', 'gdi32.GetEnhMetaFileDescriptionW', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getenhmetafileheader':( 'int', None, 'stdcall', 'gdi32.GetEnhMetaFileHeader', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.getenhmetafilepaletteentries':( 'int', None, 'stdcall', 'gdi32.GetEnhMetaFilePaletteEntries', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getenhmetafilepixelformat':( 'int', None, 'stdcall', 'gdi32.GetEnhMetaFilePixelFormat', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.getenhmetafilew':( 'int', None, 'stdcall', 'gdi32.GetEnhMetaFileW', (('void *', 'ptr'),) ),
    'gdi32.getfontassocstatus':( 'int', None, 'stdcall', 'gdi32.GetFontAssocStatus', (('int', None),) ),
    'gdi32.getfontdata':( 'int', None, 'stdcall', 'gdi32.GetFontData', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getfontlanguageinfo':( 'int', None, 'stdcall', 'gdi32.GetFontLanguageInfo', (('int', None),) ),
    'gdi32.getfontresourceinfow':( 'int', None, 'stdcall', 'gdi32.GetFontResourceInfoW', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getfontunicoderanges':( 'int', None, 'stdcall', 'gdi32.GetFontUnicodeRanges', (('int', None), ('int', None)) ),
    'gdi32.getglyphindicesa':( 'int', None, 'stdcall', 'gdi32.GetGlyphIndicesA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.getglyphindicesw':( 'int', None, 'stdcall', 'gdi32.GetGlyphIndicesW', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.getglyphoutline':( 'int', None, 'stdcall', 'gdi32.GetGlyphOutline', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getglyphoutlinea':( 'int', None, 'stdcall', 'gdi32.GetGlyphOutlineA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getglyphoutlinew':( 'int', None, 'stdcall', 'gdi32.GetGlyphOutlineW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getglyphoutlinewow':( 'int', None, 'stdcall', 'gdi32.GetGlyphOutlineWow', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getgraphicsmode':( 'int', None, 'stdcall', 'gdi32.GetGraphicsMode', (('int', None),) ),
    'gdi32.gethfont':( 'int', None, 'stdcall', 'gdi32.GetHFONT', (('int', None),) ),
    'gdi32.geticmprofilea':( 'int', None, 'stdcall', 'gdi32.GetICMProfileA', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.geticmprofilew':( 'int', None, 'stdcall', 'gdi32.GetICMProfileW', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'gdi32.getkerningpairs':( 'int', None, 'stdcall', 'gdi32.GetKerningPairs', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getkerningpairsa':( 'int', None, 'stdcall', 'gdi32.GetKerningPairsA', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getkerningpairsw':( 'int', None, 'stdcall', 'gdi32.GetKerningPairsW', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getlayout':( 'int', None, 'stdcall', 'gdi32.GetLayout', (('int', None),) ),
    'gdi32.getlogcolorspacea':( 'int', None, 'stdcall', 'gdi32.GetLogColorSpaceA', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.getlogcolorspacew':( 'int', None, 'stdcall', 'gdi32.GetLogColorSpaceW', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.getmapmode':( 'int', None, 'stdcall', 'gdi32.GetMapMode', (('int', None),) ),
    'gdi32.getmetafilea':( 'int', None, 'stdcall', 'gdi32.GetMetaFileA', (('int', None),) ),
    'gdi32.getmetafilebitsex':( 'int', None, 'stdcall', 'gdi32.GetMetaFileBitsEx', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getmetafilew':( 'int', None, 'stdcall', 'gdi32.GetMetaFileW', (('void *', 'ptr'),) ),
    'gdi32.getmetargn':( 'int', None, 'stdcall', 'gdi32.GetMetaRgn', (('int', None), ('int', None)) ),
    'gdi32.getmiterlimit':( 'int', None, 'stdcall', 'gdi32.GetMiterLimit', (('int', None), ('int', None)) ),
    'gdi32.getnearestcolor':( 'int', None, 'stdcall', 'gdi32.GetNearestColor', (('int', None), ('int', None)) ),
    'gdi32.getnearestpaletteindex':( 'int', None, 'stdcall', 'gdi32.GetNearestPaletteIndex', (('int', None), ('int', None)) ),
    'gdi32.getobjecta':( 'int', None, 'stdcall', 'gdi32.GetObjectA', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.getobjecttype':( 'int', None, 'stdcall', 'gdi32.GetObjectType', (('int', None),) ),
    'gdi32.getobjectw':( 'int', None, 'stdcall', 'gdi32.GetObjectW', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.getoutlinetextmetricsa':( 'int', None, 'stdcall', 'gdi32.GetOutlineTextMetricsA', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getoutlinetextmetricsw':( 'int', None, 'stdcall', 'gdi32.GetOutlineTextMetricsW', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getpaletteentries':( 'int', None, 'stdcall', 'gdi32.GetPaletteEntries', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getpath':( 'int', None, 'stdcall', 'gdi32.GetPath', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getpixel':( 'int', None, 'stdcall', 'gdi32.GetPixel', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getpixelformat':( 'int', None, 'stdcall', 'gdi32.GetPixelFormat', ( ('int', None),) ),
    'gdi32.getpolyfillmode':( 'int', None, 'stdcall', 'gdi32.GetPolyFillMode', (('int', None),) ),
    'gdi32.getrop2':( 'int', None, 'stdcall', 'gdi32.GetROP2', (('int', None),) ),
    'gdi32.getrandomrgn':( 'int', None, 'stdcall', 'gdi32.GetRandomRgn', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getrasterizercaps':( 'int', None, 'stdcall', 'gdi32.GetRasterizerCaps', (('int', None), ('int', None)) ),
    'gdi32.getregiondata':( 'int', None, 'stdcall', 'gdi32.GetRegionData', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.getrelabs':( 'int', None, 'stdcall', 'gdi32.GetRelAbs', (('int', None), ('int', None)) ),
    'gdi32.getrgnbox':( 'int', None, 'stdcall', 'gdi32.GetRgnBox', (('int', None), ('int', None)) ),
    'gdi32.getstockobject':( 'int', None, 'stdcall', 'gdi32.GetStockObject', (('int', None),) ),
    'gdi32.getstretchbltmode':( 'int', None, 'stdcall', 'gdi32.GetStretchBltMode', (('int', None),) ),
    'gdi32.getstringbitmapa':( 'int', None, 'stdcall', 'gdi32.GetStringBitmapA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getstringbitmapw':( 'int', None, 'stdcall', 'gdi32.GetStringBitmapW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getsystempaletteentries':( 'int', None, 'stdcall', 'gdi32.GetSystemPaletteEntries', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getsystempaletteuse':( 'int', None, 'stdcall', 'gdi32.GetSystemPaletteUse', (('int', None),) ),
    'gdi32.gettextalign':( 'int', None, 'stdcall', 'gdi32.GetTextAlign', (('int', None),) ),
    'gdi32.gettextcharacterextra':( 'int', None, 'stdcall', 'gdi32.GetTextCharacterExtra', (('int', None),) ),
    'gdi32.gettextcharset':( 'int', None, 'stdcall', 'gdi32.GetTextCharset', (('int', None),) ),
    'gdi32.gettextcharsetinfo':( 'int', None, 'stdcall', 'gdi32.GetTextCharsetInfo', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.gettextcolor':( 'int', None, 'stdcall', 'gdi32.GetTextColor', (('int', None),) ),
    'gdi32.gettextextentexpointa':( 'int', None, 'stdcall', 'gdi32.GetTextExtentExPointA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.gettextextentexpointi':( 'int', None, 'stdcall', 'gdi32.GetTextExtentExPointI', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.gettextextentexpointw':( 'int', None, 'stdcall', 'gdi32.GetTextExtentExPointW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.gettextextentexpointwpri':( 'int', None, 'stdcall', 'gdi32.GetTextExtentExPointWPri', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.gettextextentpoint32a':( 'int', None, 'stdcall', 'gdi32.GetTextExtentPoint32A', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gettextextentpoint32w':( 'int', None, 'stdcall', 'gdi32.GetTextExtentPoint32W', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gettextextentpointa':( 'int', None, 'stdcall', 'gdi32.GetTextExtentPointA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.gettextextentpointi':( 'int', None, 'stdcall', 'gdi32.GetTextExtentPointI', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.gettextextentpointw':( 'int', None, 'stdcall', 'gdi32.GetTextExtentPointW', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.gettextfacea':( 'int', None, 'stdcall', 'gdi32.GetTextFaceA', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.gettextfacealiasw':( 'int', None, 'stdcall', 'gdi32.GetTextFaceAliasW', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.gettextfacew':( 'int', None, 'stdcall', 'gdi32.GetTextFaceW', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.gettextmetricsa':( 'int', None, 'stdcall', 'gdi32.GetTextMetricsA', (('int', None), ('void *', 'ptr')) ),
    'gdi32.gettextmetricsw':( 'int', None, 'stdcall', 'gdi32.GetTextMetricsW', (('int', None), ('void *', 'ptr')) ),
    'gdi32.gettransform':( 'int', None, 'stdcall', 'gdi32.GetTransform', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.getviewportextex':( 'int', None, 'stdcall', 'gdi32.GetViewportExtEx', (('int', None), ('void *', 'ptr')) ),
    'gdi32.getviewportorgex':( 'int', None, 'stdcall', 'gdi32.GetViewportOrgEx', (('int', None), ('void *', 'ptr')) ),
    'gdi32.getwinmetafilebits':( 'int', None, 'stdcall', 'gdi32.GetWinMetaFileBits', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.getwindowextex':( 'int', None, 'stdcall', 'gdi32.GetWindowExtEx', (('int', None), ('void *', 'ptr')) ),
    'gdi32.getwindoworgex':( 'int', None, 'stdcall', 'gdi32.GetWindowOrgEx', (('int', None), ('void *', 'ptr')) ),
    'gdi32.getworldtransform':( 'int', None, 'stdcall', 'gdi32.GetWorldTransform', (('int', None), ('void *', 'ptr')) ),
    'gdi32.ht_get8bppformatpalette':( 'int', None, 'stdcall', 'gdi32.HT_Get8BPPFormatPalette', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.ht_get8bppmaskpalette':( 'int', None, 'stdcall', 'gdi32.HT_Get8BPPMaskPalette', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.intersectcliprect':( 'int', None, 'stdcall', 'gdi32.IntersectClipRect', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.invertrgn':( 'int', None, 'stdcall', 'gdi32.InvertRgn', (('int', None), ('int', None)) ),
    'gdi32.isvalidenhmetarecord':( 'int', None, 'stdcall', 'gdi32.IsValidEnhMetaRecord', (('int', None), ('int', None)) ),
    'gdi32.isvalidenhmetarecordoffext':( 'int', None, 'stdcall', 'gdi32.IsValidEnhMetaRecordOffExt', (('int', None), ('void *', 'obj'), ('int', None), ('int', None)) ),
    'gdi32.lptodp':( 'int', None, 'stdcall', 'gdi32.LPtoDP', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.linedda':( 'int', None, 'stdcall', 'gdi32.LineDDA', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'gdi32.lineto':( 'int', None, 'stdcall', 'gdi32.LineTo', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.maskblt':( 'int', None, 'stdcall', 'gdi32.MaskBlt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.mirrorrgn':( 'int', None, 'stdcall', 'gdi32.MirrorRgn', (('int', None), ('int', None)) ),
    'gdi32.modifyworldtransform':( 'int', None, 'stdcall', 'gdi32.ModifyWorldTransform', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.movetoex':( 'int', None, 'stdcall', 'gdi32.MoveToEx', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.namedescape':( 'int', None, 'stdcall', 'gdi32.NamedEscape', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.offsetcliprgn':( 'int', None, 'stdcall', 'gdi32.OffsetClipRgn', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.offsetrgn':( 'int', None, 'stdcall', 'gdi32.OffsetRgn', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.offsetviewportorgex':( 'int', None, 'stdcall', 'gdi32.OffsetViewportOrgEx', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.offsetwindoworgex':( 'int', None, 'stdcall', 'gdi32.OffsetWindowOrgEx', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.pathobj_benum':( 'int', None, 'stdcall', 'gdi32.PATHOBJ_bEnum', (('int', None), ('int', None)) ),
    'gdi32.pathobj_benumcliplines':( 'int', None, 'stdcall', 'gdi32.PATHOBJ_bEnumClipLines', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.pathobj_venumstart':( 'int', None, 'stdcall', 'gdi32.PATHOBJ_vEnumStart', (('int', None),) ),
    'gdi32.pathobj_venumstartcliplines':( 'int', None, 'stdcall', 'gdi32.PATHOBJ_vEnumStartClipLines', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.pathobj_vgetbounds':( 'int', None, 'stdcall', 'gdi32.PATHOBJ_vGetBounds', (('int', None), ('int', None)) ),
    'gdi32.paintrgn':( 'int', None, 'stdcall', 'gdi32.PaintRgn', (('int', None), ('int', None)) ),
    'gdi32.patblt':( 'int', None, 'stdcall', 'gdi32.PatBlt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.pathtoregion':( 'int', None, 'stdcall', 'gdi32.PathToRegion', (('int', None),) ),
    'gdi32.pie':( 'int', None, 'stdcall', 'gdi32.Pie', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.playenhmetafile':( 'int', None, 'stdcall', 'gdi32.PlayEnhMetaFile', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.playenhmetafilerecord':( 'int', None, 'stdcall', 'gdi32.PlayEnhMetaFileRecord', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.playmetafile':( 'int', None, 'stdcall', 'gdi32.PlayMetaFile', (('int', None), ('int', None)) ),
    'gdi32.playmetafilerecord':( 'int', None, 'stdcall', 'gdi32.PlayMetaFileRecord', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.plgblt':( 'int', None, 'stdcall', 'gdi32.PlgBlt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.polybezier':( 'int', None, 'stdcall', 'gdi32.PolyBezier', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.polybezierto':( 'int', None, 'stdcall', 'gdi32.PolyBezierTo', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.polydraw':( 'int', None, 'stdcall', 'gdi32.PolyDraw', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.polypatblt':( 'int', None, 'stdcall', 'gdi32.PolyPatBlt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.polypolygon':( 'int', None, 'stdcall', 'gdi32.PolyPolygon', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.polypolyline':( 'int', None, 'stdcall', 'gdi32.PolyPolyline', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.polytextouta':( 'int', None, 'stdcall', 'gdi32.PolyTextOutA', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.polytextoutw':( 'int', None, 'stdcall', 'gdi32.PolyTextOutW', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.polygon':( 'int', None, 'stdcall', 'gdi32.Polygon', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.polyline':( 'int', None, 'stdcall', 'gdi32.Polyline', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.polylineto':( 'int', None, 'stdcall', 'gdi32.PolylineTo', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.ptinregion':( 'int', None, 'stdcall', 'gdi32.PtInRegion', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.ptvisible':( 'int', None, 'stdcall', 'gdi32.PtVisible', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.queryfontassocstatus':( 'int', None, 'cdecl', 'gdi32.QueryFontAssocStatus', () ),
    'gdi32.realizepalette':( 'int', None, 'stdcall', 'gdi32.RealizePalette', (('int', None),) ),
    'gdi32.rectinregion':( 'int', None, 'stdcall', 'gdi32.RectInRegion', (('int', None), ('int', None)) ),
    'gdi32.rectvisible':( 'int', None, 'stdcall', 'gdi32.RectVisible', (('int', None), ('int', None)) ),
    'gdi32.rectangle':( 'int', None, 'stdcall', 'gdi32.Rectangle', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.removefontmemresourceex':( 'int', None, 'stdcall', 'gdi32.RemoveFontMemResourceEx', (('int', None),) ),
    'gdi32.removefontresourcea':( 'int', None, 'stdcall', 'gdi32.RemoveFontResourceA', (('int', None),) ),
    'gdi32.removefontresourceexa':( 'int', None, 'stdcall', 'gdi32.RemoveFontResourceExA', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.removefontresourceexw':( 'int', None, 'stdcall', 'gdi32.RemoveFontResourceExW', ( ('int', None), ('int', None), ('int', None)) ),
    'gdi32.removefontresourcetracking':( 'int', None, 'stdcall', 'gdi32.RemoveFontResourceTracking', ( ('int', None), ('int', None)) ),
    'gdi32.removefontresourcew':( 'int', None, 'stdcall', 'gdi32.RemoveFontResourceW', ( ('void *', 'ptr'),) ),
    'gdi32.resetdca':( 'int', None, 'stdcall', 'gdi32.ResetDCA', (('int', None), ('int', None)) ),
    'gdi32.resetdcw':( 'int', None, 'stdcall', 'gdi32.ResetDCW', (('int', None), ('int', None)) ),
    'gdi32.resizepalette':( 'int', None, 'stdcall', 'gdi32.ResizePalette', (('int', None), ('int', None)) ),
    'gdi32.restoredc':( 'int', None, 'stdcall', 'gdi32.RestoreDC', (('int', None), ('int', None)) ),
    'gdi32.roundrect':( 'int', None, 'stdcall', 'gdi32.RoundRect', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.strobj_benum':( 'int', None, 'stdcall', 'gdi32.STROBJ_bEnum', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.strobj_benumpositionsonly':( 'int', None, 'stdcall', 'gdi32.STROBJ_bEnumPositionsOnly', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.strobj_bgetadvancewidths':( 'int', None, 'stdcall', 'gdi32.STROBJ_bGetAdvanceWidths', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.strobj_dwgetcodepage':( 'int', None, 'stdcall', 'gdi32.STROBJ_dwGetCodePage', (('int', None),) ),
    'gdi32.strobj_venumstart':( 'int', None, 'stdcall', 'gdi32.STROBJ_vEnumStart', (('int', None),) ),
    'gdi32.savedc':( 'int', None, 'stdcall', 'gdi32.SaveDC', (('int', None),) ),
    'gdi32.scaleviewportextex':( 'int', None, 'stdcall', 'gdi32.ScaleViewportExtEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.scalewindowextex':( 'int', None, 'stdcall', 'gdi32.ScaleWindowExtEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.selectbrushlocal':( 'int', None, 'stdcall', 'gdi32.SelectBrushLocal', (('int', None), ('int', None)) ),
    'gdi32.selectclippath':( 'int', None, 'stdcall', 'gdi32.SelectClipPath', (('int', None), ('int', None)) ),
    'gdi32.selectcliprgn':( 'int', None, 'stdcall', 'gdi32.SelectClipRgn', (('int', None), ('int', None)) ),
    'gdi32.selectfontlocal':( 'int', None, 'stdcall', 'gdi32.SelectFontLocal', (('int', None), ('int', None)) ),
    'gdi32.selectobject':( 'int', None, 'stdcall', 'gdi32.SelectObject', (('int', None), ('int', None)) ),
    'gdi32.selectpalette':( 'int', None, 'stdcall', 'gdi32.SelectPalette', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.setabortproc':( 'int', None, 'stdcall', 'gdi32.SetAbortProc', (('int', None), ('int', None)) ),
    'gdi32.setarcdirection':( 'int', None, 'stdcall', 'gdi32.SetArcDirection', (('int', None), ('int', None)) ),
    'gdi32.setbitmapattributes':( 'int', None, 'stdcall', 'gdi32.SetBitmapAttributes', (('int', None), ('int', None)) ),
    'gdi32.setbitmapbits':( 'int', None, 'stdcall', 'gdi32.SetBitmapBits', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.setbitmapdimensionex':( 'int', None, 'stdcall', 'gdi32.SetBitmapDimensionEx', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setbkcolor':( 'int', None, 'stdcall', 'gdi32.SetBkColor', (('int', None), ('int', None)) ),
    'gdi32.setbkmode':( 'int', None, 'stdcall', 'gdi32.SetBkMode', (('int', None), ('int', None)) ),
    'gdi32.setboundsrect':( 'int', None, 'stdcall', 'gdi32.SetBoundsRect', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.setbrushattributes':( 'int', None, 'stdcall', 'gdi32.SetBrushAttributes', (('int', None), ('int', None)) ),
    'gdi32.setbrushorgex':( 'int', None, 'stdcall', 'gdi32.SetBrushOrgEx', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.setcoloradjustment':( 'int', None, 'stdcall', 'gdi32.SetColorAdjustment', (('int', None), ('int', None)) ),
    'gdi32.setcolorspace':( 'int', None, 'stdcall', 'gdi32.SetColorSpace', (('int', None), ('int', None)) ),
    'gdi32.setdcbrushcolor':( 'int', None, 'stdcall', 'gdi32.SetDCBrushColor', (('int', None), ('int', None)) ),
    'gdi32.setdcpencolor':( 'int', None, 'stdcall', 'gdi32.SetDCPenColor', (('int', None), ('int', None)) ),
    'gdi32.setdibcolortable':( 'int', None, 'stdcall', 'gdi32.SetDIBColorTable', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setdibits':( 'int', None, 'stdcall', 'gdi32.SetDIBits', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setdibitstodevice':( 'int', None, 'stdcall', 'gdi32.SetDIBitsToDevice', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.setdevicegammaramp':( 'int', None, 'stdcall', 'gdi32.SetDeviceGammaRamp', (('int', None), ('int', None)) ),
    'gdi32.setenhmetafilebits':( 'int', None, 'stdcall', 'gdi32.SetEnhMetaFileBits', (('int', None), ('int', None)) ),
    'gdi32.setfontenumeration':( 'int', None, 'stdcall', 'gdi32.SetFontEnumeration', (('int', None),) ),
    'gdi32.setgraphicsmode':( 'int', None, 'stdcall', 'gdi32.SetGraphicsMode', (('int', None), ('int', None)) ),
    'gdi32.seticmmode':( 'int', None, 'stdcall', 'gdi32.SetICMMode', (('int', None), ('int', None)) ),
    'gdi32.seticmprofilea':( 'int', None, 'stdcall', 'gdi32.SetICMProfileA', ( ('int', None), ('void *', 'ptr')) ),
    'gdi32.seticmprofilew':( 'int', None, 'stdcall', 'gdi32.SetICMProfileW', ( ('int', None), ('void *', 'ptr')) ),
    'gdi32.setlayout':( 'int', None, 'stdcall', 'gdi32.SetLayout', (('int', None), ('int', None)) ),
    'gdi32.setlayoutwidth':( 'int', None, 'stdcall', 'gdi32.SetLayoutWidth', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.setmagiccolors':( 'int', None, 'stdcall', 'gdi32.SetMagicColors', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.setmapmode':( 'int', None, 'stdcall', 'gdi32.SetMapMode', (('int', None), ('int', None)) ),
    'gdi32.setmapperflags':( 'int', None, 'stdcall', 'gdi32.SetMapperFlags', (('int', None), ('int', None)) ),
    'gdi32.setmetafilebitsex':( 'int', None, 'stdcall', 'gdi32.SetMetaFileBitsEx', (('int', None), ('int', None)) ),
    'gdi32.setmetargn':( 'int', None, 'stdcall', 'gdi32.SetMetaRgn', (('int', None),) ),
    'gdi32.setmiterlimit':( 'int', None, 'stdcall', 'gdi32.SetMiterLimit', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.setpaletteentries':( 'int', None, 'stdcall', 'gdi32.SetPaletteEntries', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setpixel':( 'int', None, 'stdcall', 'gdi32.SetPixel', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setpixelformat':( 'int', None, 'stdcall', 'gdi32.SetPixelFormat', ( ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.setpixelv':( 'int', None, 'stdcall', 'gdi32.SetPixelV', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setpolyfillmode':( 'int', None, 'stdcall', 'gdi32.SetPolyFillMode', (('int', None), ('int', None)) ),
    'gdi32.setrop2':( 'int', None, 'stdcall', 'gdi32.SetROP2', (('int', None), ('int', None)) ),
    'gdi32.setrectrgn':( 'int', None, 'stdcall', 'gdi32.SetRectRgn', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setrelabs':( 'int', None, 'stdcall', 'gdi32.SetRelAbs', (('int', None), ('int', None)) ),
    'gdi32.setstretchbltmode':( 'int', None, 'stdcall', 'gdi32.SetStretchBltMode', (('int', None), ('int', None)) ),
    'gdi32.setsystempaletteuse':( 'int', None, 'stdcall', 'gdi32.SetSystemPaletteUse', (('int', None), ('int', None)) ),
    'gdi32.settextalign':( 'int', None, 'stdcall', 'gdi32.SetTextAlign', (('int', None), ('int', None)) ),
    'gdi32.settextcharacterextra':( 'int', None, 'stdcall', 'gdi32.SetTextCharacterExtra', (('int', None), ('int', None)) ),
    'gdi32.settextcolor':( 'int', None, 'stdcall', 'gdi32.SetTextColor', (('int', None), ('int', None)) ),
    'gdi32.settextjustification':( 'int', None, 'stdcall', 'gdi32.SetTextJustification', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.setviewportextex':( 'int', None, 'stdcall', 'gdi32.SetViewportExtEx', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setviewportorgex':( 'int', None, 'stdcall', 'gdi32.SetViewportOrgEx', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setvirtualresolution':( 'int', None, 'stdcall', 'gdi32.SetVirtualResolution', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setwinmetafilebits':( 'int', None, 'stdcall', 'gdi32.SetWinMetaFileBits', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'gdi32.setwindowextex':( 'int', None, 'stdcall', 'gdi32.SetWindowExtEx', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setwindoworgex':( 'int', None, 'stdcall', 'gdi32.SetWindowOrgEx', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.setworldtransform':( 'int', None, 'stdcall', 'gdi32.SetWorldTransform', (('int', None), ('void *', 'ptr')) ),
    'gdi32.startdoca':( 'int', None, 'stdcall', 'gdi32.StartDocA', (('int', None), ('void *', 'ptr')) ),
    'gdi32.startdocw':( 'int', None, 'stdcall', 'gdi32.StartDocW', (('int', None), ('void *', 'ptr')) ),
    'gdi32.startformpage':( 'int', None, 'stdcall', 'gdi32.StartFormPage', (('int', None),) ),
    'gdi32.startpage':( 'int', None, 'stdcall', 'gdi32.StartPage', (('int', None),) ),
    'gdi32.stretchblt':( 'int', None, 'stdcall', 'gdi32.StretchBlt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.stretchdibits':( 'int', None, 'stdcall', 'gdi32.StretchDIBits', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'gdi32.strokeandfillpath':( 'int', None, 'stdcall', 'gdi32.StrokeAndFillPath', (('int', None),) ),
    'gdi32.strokepath':( 'int', None, 'stdcall', 'gdi32.StrokePath', (('int', None),) ),
    'gdi32.swapbuffers':( 'int', None, 'stdcall', 'gdi32.SwapBuffers', ( ('int', None),) ),
    'gdi32.textouta':( 'int', None, 'stdcall', 'gdi32.TextOutA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('DWORD', None)) ),
    'gdi32.textoutw':( 'int', None, 'stdcall', 'gdi32.TextOutW', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('DWORD', None)) ),
    'gdi32.translatecharsetinfo':( 'int', None, 'stdcall', 'gdi32.TranslateCharsetInfo', (('int', None), ('int', None), ('int', None)) ),
    'gdi32.unloadnetworkfonts':( 'int', None, 'stdcall', 'gdi32.UnloadNetworkFonts', ( ('int', None),) ),
    'gdi32.unrealizeobject':( 'int', None, 'stdcall', 'gdi32.UnrealizeObject', (('int', None),) ),
    'gdi32.updatecolors':( 'int', None, 'stdcall', 'gdi32.UpdateColors', (('int', None),) ),
    'gdi32.updateicmregkeya':( 'int', None, 'stdcall', 'gdi32.UpdateICMRegKeyA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.updateicmregkeyw':( 'int', None, 'stdcall', 'gdi32.UpdateICMRegKeyW', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.widenpath':( 'int', None, 'stdcall', 'gdi32.WidenPath', (('int', None),) ),
    'gdi32.xformobj_bapplyxform':( 'int', None, 'stdcall', 'gdi32.XFORMOBJ_bApplyXform', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.xformobj_igetxform':( 'int', None, 'stdcall', 'gdi32.XFORMOBJ_iGetXform', (('int', None), ('int', None)) ),
    'gdi32.xlateobj_cgetpalette':( 'int', None, 'stdcall', 'gdi32.XLATEOBJ_cGetPalette', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'gdi32.xlateobj_hgetcolortransform':( 'int', None, 'stdcall', 'gdi32.XLATEOBJ_hGetColorTransform', (('int', None),) ),
    'gdi32.xlateobj_ixlate':( 'int', None, 'stdcall', 'gdi32.XLATEOBJ_iXlate', (('int', None), ('int', None)) ),
    'gdi32.xlateobj_pivector':( 'int', None, 'stdcall', 'gdi32.XLATEOBJ_piVector', (('int', None),) ),
    'gdi32.binitsystemandfontsdirectoriesw':( 'int', None, 'stdcall', 'gdi32.bInitSystemAndFontsDirectoriesW', (('int', None), ('int', None)) ),
    'gdi32.bmakepathnamew':( 'int', None, 'stdcall', 'gdi32.bMakePathNameW', (('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.cgetttffromfot':( 'int', None, 'stdcall', 'gdi32.cGetTTFFromFOT', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'gdi32.gdiplayspoolstream':( 'int', None, 'stdcall', 'gdi32.gdiPlaySpoolStream', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    }



## ELF IDENT index constants
# EI_NIDENT differs from sys/elf.h because we only use this to indicate the \x7fELF, but break out the individual
# fields (class/data/fileversion/osabi/abiversion/padding) in the Elf Header vstruct, instead of making them just
# part of the char array.
EI_NIDENT = 4
EI_PADLEN = 7

## EM enumeration definitions
EM_NONE = 0
EM_M32 = 1
EM_SPARC = 2
EM_386 = 3
EM_68K = 4
EM_88K = 5
EM_860 = 7
EM_MIPS = 8
EM_S370 = 9
EM_MIPS_RS3_LE = 10
EM_PARISC = 15
EM_VPP500 = 17
EM_SPARC32PLUS = 18
EM_960 = 19
EM_PPC = 20
EM_PPC64 = 21
EM_S390 = 22
EM_V800 = 36
EM_FR20 = 37
EM_RH32 = 38
EM_RCE = 39
EM_ARM = 40
EM_FAKE_ALPHA = 41
EM_SH = 42
EM_SPARCV9 = 43
EM_TRICORE = 44
EM_ARC = 45
EM_H8_300 = 46
EM_H8_300H = 47
EM_H8S = 48
EM_H8_500 = 49
EM_IA_64 = 50
EM_MIPS_X = 51
EM_COLDFIRE = 52
EM_68HC12 = 53
EM_MMA = 54
EM_PCP = 55
EM_NCPU = 56
EM_NDR1 = 57
EM_STARCORE = 58
EM_ME16 = 59
EM_ST100 = 60
EM_TINYJ = 61
EM_X86_64 = 62
EM_PDSP = 63
EM_FX66 = 66
EM_ST9PLUS = 67
EM_ST7 = 68
EM_68HC16 = 69
EM_68HC11 = 70
EM_68HC08 = 71
EM_68HC05 = 72
EM_SVX = 73
EM_ST19 = 74
EM_VAX = 75
EM_CRIS = 76
EM_JAVELIN = 77
EM_FIREPATH = 78
EM_ZSP = 79
EM_MMIX = 80
EM_HUANY = 81
EM_PRISM = 82
EM_AVR = 83
EM_FR30 = 84
EM_D10V = 85
EM_D30V = 86
EM_V850 = 87
EM_M32R = 88
EM_MN10300 = 89
EM_MN10200 = 90
EM_PJ = 91
EM_OPENRISC = 92
EM_ARC_A5 = 93
EM_XTENSA = 94
EM_NUM = 95
EM_MSP430 = 105
EM_ARM_A64 = 183
EM_ALPHA = 0x9026

# There are plenty more of these to
# fill in, but...  this is all I need
# for now...
e_machine_32 =  (
                EM_386,
                EM_PPC,
                EM_ARM,
                )
e_machine_64 =  (
                EM_PPC64,
                EM_SPARCV9,
                EM_X86_64,
                EM_ARM_A64,
                )

ELFCLASSNONE = 0
ELFCLASS32 = 1 # 32-bit object file
ELFCLASS64 = 2 # 64-bit object file

ELFDATANONE = 0
ELFDATA2LSB = 1
ELFDATA2MSB = 2

e_machine_types = {
    EM_NONE:"No machine",
    EM_M32:"AT&T WE 32100",
    EM_SPARC:"SUN SPARC",
    EM_386:"Intel 80386",
    EM_68K:"Motorola m68k family",
    EM_88K:"Motorola m88k family",
    EM_860:"Intel 80860",
    EM_MIPS:"MIPS R3000 big-endian",
    EM_S370:"IBM System/370",
    EM_MIPS_RS3_LE:"MIPS R3000 little-endian",
    EM_PARISC:"HPPA",
    EM_VPP500:"Fujitsu VPP500",
    EM_SPARC32PLUS:"Suns v8plus",
    EM_960:"Intel 80960",
    EM_PPC:"PowerPC",
    EM_PPC64:"PowerPC 64-bit",
    EM_S390:"IBM S390",
    EM_V800:"NEC V800 series",
    EM_FR20:"Fujitsu FR20",
    EM_RH32:"TRW RH-32",
    EM_RCE:"Motorola RCE",
    EM_ARM:"ARM",
    EM_FAKE_ALPHA:"Digital Alpha",
    EM_SH:"Hitachi SH",
    EM_SPARCV9:"SPARC v9 64-bit",
    EM_TRICORE:"Siemens Tricore",
    EM_ARC:"Argonaut RISC Core",
    EM_H8_300:"Hitachi H8/300",
    EM_H8_300H:"Hitachi H8/300H",
    EM_H8S:"Hitachi H8S",
    EM_H8_500:"Hitachi H8/500",
    EM_IA_64:"Intel Merced",
    EM_MIPS_X:"Stanford MIPS-X",
    EM_COLDFIRE:"Motorola Coldfire",
    EM_68HC12:"Motorola M68HC12",
    EM_MMA:"Fujitsu MMA Multimedia",
    EM_PCP:"Siemens PCP",
    EM_NCPU:"Sony nCPU embeeded RISC",
    EM_NDR1:"Denso NDR1 microprocessor",
    EM_STARCORE:"Motorola Start*Core processor",
    EM_ME16:"Toyota ME16 processor",
    EM_ST100:"STMicroelectronic ST100 processor",
    EM_TINYJ:"Advanced Logic Corp. Tinyj",
    EM_X86_64:"AMD x86-64 architecture",
    EM_PDSP:"Sony DSP Processor",
    EM_FX66:"Siemens FX66 microcontroller",
    EM_ST9PLUS:"STMicroelectronics ST9+ 8/16 mc",
    EM_ST7:"STmicroelectronics ST7 8 bit mc",
    EM_68HC16:"Motorola MC68HC16 microcontroller",
    EM_68HC11:"Motorola MC68HC11 microcontroller",
    EM_68HC08:"Motorola MC68HC08 microcontroller",
    EM_68HC05:"Motorola MC68HC05 microcontroller",
    EM_SVX:"Silicon Graphics SVx",
    EM_ST19:"STMicroelectronics ST19 8 bit mc",
    EM_VAX:"Digital VAX",
    EM_CRIS:"Axis Communications 32-bit embedded processor",
    EM_JAVELIN:"Infineon Technologies 32-bit embedded processor",
    EM_FIREPATH:"Element 14 64-bit DSP Processor",
    EM_ZSP:"LSI Logic 16-bit DSP Processor",
    EM_MMIX:"Donald Knuths educational 64-bit processor",
    EM_HUANY:"Harvard University machine-independent object files",
    EM_PRISM:"SiTera Prism",
    EM_AVR:"Atmel AVR 8-bit microcontroller",
    EM_FR30:"Fujitsu FR30",
    EM_D10V:"Mitsubishi D10V",
    EM_D30V:"Mitsubishi D30V",
    EM_V850:"NEC v850",
    EM_M32R:"Mitsubishi M32R",
    EM_MN10300:"Matsushita MN10300",
    EM_MN10200:"Matsushita MN10200",
    EM_PJ:"picoJava",
    EM_OPENRISC:"OpenRISC 32-bit embedded processor",
    EM_ARC_A5:"ARC Cores Tangent-A5",
    EM_XTENSA:"Tensilica Xtensa Architecture",
    EM_NUM:"",
    EM_ARM_A64:"ARM a64",
    EM_ALPHA:"",
}

ET_NONE = 0
ET_REL = 1
ET_EXEC = 2
ET_DYN = 3
ET_CORE = 4
ET_NUM = 5
ET_LOOS = 0xfe00
ET_HIOS = 0xfeff
ET_LOPROC = 0xff00
ET_HIPROC = 0xffff

e_types = {
    ET_NONE:"No file type",
    ET_REL:"Relocatable file",
    ET_EXEC:"Executable file",
    ET_DYN:"Shared object file",
    ET_CORE:"Core file",
    ET_NUM:"Number of defined types",
    ET_LOOS:"OS-specific range start",
    ET_HIOS:"OS-specific range end",
    ET_LOPROC:"Processor-specific range start",
    ET_HIPROC:"Processor-specific range end",
}

EV_NONE = 0
EV_CURRENT = 1
EV_NUM = 2

e_versions = {
    EV_NONE:"Invalid ELF version",
    EV_CURRENT:"Current version",
    EV_NUM:"",
}

R_68K_NONE = 0
R_68K_32 = 1
R_68K_16 = 2
R_68K_8 = 3
R_68K_PC32 = 4
R_68K_PC16 = 5
R_68K_PC8 = 6
R_68K_GOT32 = 7
R_68K_GOT16 = 8
R_68K_GOT8 = 9
R_68K_GOT32O = 10
R_68K_GOT16O = 11
R_68K_GOT8O = 12
R_68K_PLT32 = 13
R_68K_PLT16 = 14
R_68K_PLT8 = 15
R_68K_PLT32O = 16
R_68K_PLT16O = 17
R_68K_PLT8O = 18
R_68K_COPY = 19
R_68K_GLOB_DAT = 20
R_68K_JMP_SLOT = 21
R_68K_RELATIVE = 22

e_flags_68k = {
    R_68K_NONE:"No reloc",
    R_68K_32:"Direct 32 bit",
    R_68K_16:"Direct 16 bit",
    R_68K_8:"Direct 8 bit",
    R_68K_PC32:"PC relative 32 bit",
    R_68K_PC16:"PC relative 16 bit",
    R_68K_PC8:"PC relative 8 bit",
    R_68K_GOT32:"32 bit PC relative GOT entry",
    R_68K_GOT16:"16 bit PC relative GOT entry",
    R_68K_GOT8:"8 bit PC relative GOT entry",
    R_68K_GOT32O:"32 bit GOT offset",
    R_68K_GOT16O:"16 bit GOT offset",
    R_68K_GOT8O:"8 bit GOT offset",
    R_68K_PLT32:"32 bit PC relative PLT address",
    R_68K_PLT16:"16 bit PC relative PLT address",
    R_68K_PLT8:"8 bit PC relative PLT address",
    R_68K_PLT32O:"32 bit PLT offset",
    R_68K_PLT16O:"16 bit PLT offset",
    R_68K_PLT8O:"8 bit PLT offset",
    R_68K_COPY:"Copy symbol at runtime",
    R_68K_GLOB_DAT:"Create GOT entry",
    R_68K_JMP_SLOT:"Create PLT entry",
    R_68K_RELATIVE:"Adjust by program base",
}

R_ARM_NONE          = 0   # No reloc */
R_ARM_PC24          = 1   # PC relative 26 bit branch */
R_ARM_ABS32         = 2   # Direct 32 bit  */
R_ARM_REL32         = 3   # PC relative 32 bit */
R_ARM_PC13          = 4
R_ARM_LDR_PC_G0     = 4   # also 4
R_ARM_ABS16         = 5   # Direct 16 bit */
R_ARM_ABS12         = 6   # Direct 12 bit */
R_ARM_THM_ABS5      = 7
R_ARM_ABS8          = 8   # Direct 8 bit */
R_ARM_SBREL32       = 9
R_ARM_THM_PC22      = 10
R_ARM_THM_PC8       = 11
R_ARM_AMP_VCALL9    = 12
R_ARM_BREL_ADJ      = 12  # also 12
R_ARM_SWI24         = 13
R_ARM_TLS_DESC      = 13  # also 13
R_ARM_THM_SWI8      = 14
R_ARM_XPC25         = 15
R_ARM_THM_XPC22     = 16
R_ARM_TLS_DTPMOD32  = 17  # ID of module containing symbol */
R_ARM_TLS_DTPOFF32  = 18  # Offset in TLS block */
R_ARM_TLS_TPOFF32   = 19  # Offset in static TLS block */
R_ARM_COPY          = 20  # Copy symbol at runtime */
R_ARM_GLOB_DAT      = 21  # Create GOT entry */
R_ARM_JUMP_SLOT     = 22  # Create PLT entry */
R_ARM_RELATIVE      = 23  # Adjust by program base */
R_ARM_GOTOFF        = 24  # 32 bit offset to GOT */
R_ARM_GOTPC         = 25  # 32 bit PC relative offset to GOT */
R_ARM_GOT32         = 26  # 32 bit GOT entry */
R_ARM_PLT32         = 27  # 32 bit PLT address */
R_ARM_CALL          = 28
R_ARM_JUMP24        = 29
R_ARM_THM_JUMP24        = 30
R_ARM_BASE_ABS          = 31
R_ARM_ALU_PCREL_7_0     = 32
R_ARM_ALU_PCREL_15_8    = 33
R_ARM_ALU_PCREL_23_15   = 34
R_ARM_LDR_SBREL_11_0    = 35
R_ARM_ALU_SBREL_19_12   = 36
R_ARM_ALU_SBREL_27_20   = 37
R_ARM_GNU_VTENTRY   = 100
R_ARM_GNU_VTINHERIT = 101
R_ARM_THM_PC11      = 102 # thumb unconditional branch */
R_ARM_THM_PC9       = 103 # thumb conditional branch */
R_ARM_TLS_GD32      = 104 # PC-rel 32 bit for global dynamic thread local data */
R_ARM_TLS_LDM32     = 105 # PC-rel 32 bit for local dynamic thread local data */
R_ARM_TLS_LDO32     = 106 # 32 bit offset relative to TLS block */
R_ARM_TLS_IE32      = 107 # PC-rel 32 bit for GOT entry of static TLS block offset */
R_ARM_TLS_LE32      = 108 # 32 bit offset relative to static TLS block */
R_ARM_IRELATIVE     = 160
R_ARM_RXPC25        = 249
R_ARM_RSBREL32      = 250
R_ARM_THM_RPC22     = 251
R_ARM_RREL32        = 252
R_ARM_RABS22        = 253
R_ARM_RPC24         = 254
R_ARM_RBASE         = 255

R_ARMCLASS_DATA = 0
R_ARMCLASS_ARM = 1
R_ARMCLASS_THUMB16 = 2
R_ARMCLASS_THUMB32 = 3
R_ARMCLASS_MISC = 4

r_armclasses = [
        (R_ARM_ABS32,
            R_ARM_REL32,
            R_ARM_ABS16,
            R_ARM_ABS8,
            R_ARM_SBREL32,
            R_ARM_BREL_ADJ,
            R_ARM_TLS_DESC,
            R_ARM_TLS_DTPMOD32,
            R_ARM_TLS_DTPOFF32,
            R_ARM_TLS_TPOFF32,
            R_ARM_GLOB_DAT,
            R_ARM_JUMP_SLOT,
            R_ARM_RELATIVE,
            R_ARM_GOTOFF,
            R_ARM_GOTPC,
            R_ARM_GOT32,
            R_ARM_IRELATIVE,
            ),
        (
            R_ARM_PC24,
            R_ARM_LDR_PC_G0,
            R_ARM_ABS12,
            R_ARM_PLT32,
            R_ARM_CALL,
            R_ARM_JUMP24,
            R_ARM_LDR_SBREL_11_0,
            R_ARM_ALU_SBREL_19_12,
            R_ARM_ALU_SBREL_27_20,
            ),
        (
            R_ARM_THM_ABS5,
            R_ARM_THM_PC8,
            ),
        (
            R_ARM_THM_PC22,
            R_ARM_THM_JUMP24,
            ),
        (
            R_ARM_NONE,
            R_ARM_COPY,
            ),
        ]

R_AARCH64_ABS64 = 0x101
R_AARCH64_COPY = 0x400
R_AARCH64_GLOB_DAT = 0x401
R_AARCH64_JUMP_SLOT = 0x402
R_AARCH64_RELATIVE = 0x403

R_386_NONE = 0
R_386_32 = 1
R_386_PC32 = 2
R_386_GOT32 = 3
R_386_PLT32 = 4
R_386_COPY = 5
R_386_GLOB_DAT = 6
R_386_JMP_SLOT = 7
R_386_RELATIVE = 8
R_386_GOTOFF = 9
R_386_GOTPC = 10
R_386_32PLT = 11
R_386_TLS_TPOFF = 14
R_386_TLS_IE = 15
R_386_TLS_GOTIE = 16
R_386_TLS_LE = 17
R_386_TLS_GD = 18
R_386_TLS_LDM = 19
R_386_16 = 20
R_386_PC16 = 21
R_386_8 = 22
R_386_PC8 = 23
R_386_TLS_GD_32 = 24
R_386_TLS_GD_PUSH = 25
R_386_TLS_GD_CALL = 26
R_386_TLS_GD_POP = 27
R_386_TLS_LDM_32 = 28
R_386_TLS_LDM_PUSH = 29
R_386_TLS_LDM_CALL = 30
R_386_TLS_LDM_POP = 31
R_386_TLS_LDO_32 = 32
R_386_TLS_IE_32 = 33
R_386_TLS_LE_32 = 34
R_386_TLS_DTPMOD32 = 35
R_386_TLS_DTPOFF32 = 36
R_386_TLS_TPOFF32 = 37

r_types_386 = {
    R_386_NONE:"No reloc",
    R_386_32:"Direct 32 bit",
    R_386_PC32:"PC relative 32 bit",
    R_386_GOT32:"32 bit GOT entry",
    R_386_PLT32:"32 bit PLT address",
    R_386_COPY:"Copy symbol at runtime",
    R_386_GLOB_DAT:"Create GOT entry",
    R_386_JMP_SLOT:"Create PLT entry",
    R_386_RELATIVE:"Adjust by program base",
    R_386_GOTOFF:"32 bit offset to GOT",
    R_386_GOTPC:"32 bit PC relative offset to GOT",
    R_386_32PLT:"",
    R_386_TLS_TPOFF:"Offset in static TLS block",
    R_386_TLS_IE:"Address of GOT entry for static",
    R_386_TLS_GOTIE:"GOT entry for static TLS",
    R_386_TLS_LE:"Offset relative to static",
    R_386_TLS_GD:"Direct 32 bit for GNU version",
    R_386_TLS_LDM:"Direct 32 bit for GNU version",
    R_386_16:"",
    R_386_PC16:"",
    R_386_8:"",
    R_386_PC8:"",
    R_386_TLS_GD_32:"Direct 32 bit for general",
    R_386_TLS_GD_PUSH:"Tag for pushl in GD TLS code",
    R_386_TLS_GD_CALL:"Relocation for call",
    R_386_TLS_GD_POP:"Tag for popl in GD TLS code",
    R_386_TLS_LDM_32:"Direct 32 bit for local",
    R_386_TLS_LDM_PUSH:"Tag for pushl in LDM TLS code",
    R_386_TLS_LDM_CALL:"Relocation for call",
    R_386_TLS_LDM_POP:"Tag for popl in LDM TLS code",
    R_386_TLS_LDO_32:"Offset relative to TLS block",
    R_386_TLS_IE_32:"GOT entry for negated static",
    R_386_TLS_LE_32:"Negated offset relative to",
    R_386_TLS_DTPMOD32:"ID of module containing symbol",
    R_386_TLS_DTPOFF32:"Offset in TLS block",
    R_386_TLS_TPOFF32:"Negated offset in static TLS block",
}

R_X86_64_NONE        = 0
R_X86_64_64          = 1
R_X86_64_PC32        = 2
R_X86_64_GOT32       = 3
R_X86_64_PLT32       = 4
R_X86_64_COPY        = 5
R_X86_64_GLOB_DAT    = 6
R_X86_64_JUMP_SLOT   = 7
R_X86_64_RELATIVE    = 8
R_X86_64_GOTPCREL    = 9
R_X86_64_32          = 10
R_X86_64_32S         = 11
R_X86_64_16          = 12
R_X86_64_PC16        = 13
R_X86_64_8           = 14
R_X86_64_PC8         = 15
R_X86_64_DTPMOD64    = 16
R_X86_64_DTPOFF64    = 17
R_X86_64_TPOFF64     = 18
R_X86_64_TLSGD       = 19
R_X86_64_TLSLD       = 20
R_X86_64_DTPOFF32    = 21
R_X86_64_GOTTPOFF    = 22
R_X86_64_TPOFF32     = 23
R_X86_64_NUM         = 24
R_X86_64_GOTOFF64    = 25
R_X86_64_GOTPC32     = 26
R_X86_64_GOT64       = 27
R_X86_64_GOTPCREL64  = 28
R_X86_64_GOTPC64     = 29
R_X86_64_GOTPLT64    = 30
R_X86_64_PLTOFF64    = 31
R_X86_64_SIZE32      = 32
R_X86_64_SIZE64      = 33
R_X86_64_GOTPC32_TLSDESC = 34
R_X86_64_TLSDESC_CALL = 35
R_X86_64_TLSDESC     = 36
R_X86_64_IRELATIVE   = 37


r_types_amd64 = {
    R_X86_64_NONE       :'No reloc',
    R_X86_64_64         :'Direct 64 bit',
    R_X86_64_PC32       :'PC relative 32 bit signed',
    R_X86_64_GOT32      :'32 bit GOT entry',
    R_X86_64_PLT32      :'32 bit PLT address',
    R_X86_64_COPY       :'Copy symbol at runtime',
    R_X86_64_GLOB_DAT   :'Create GOT entry',
    R_X86_64_JUMP_SLOT  :'Create PLT entry',
    R_X86_64_RELATIVE   :'Adjust by program base',
    R_X86_64_GOTPCREL   :'32 bit signed PC relative offset to GOT',
    R_X86_64_32         :'Direct 32 bit zero extended',
    R_X86_64_32S        :'Direct 32 bit sign extended',
    R_X86_64_16         :'Direct 16 bit zero extended',
    R_X86_64_PC16       :'16 bit sign extended pc relative',
    R_X86_64_8          :'Direct 8 bit sign extended ',
    R_X86_64_PC8        :'8 bit sign extended pc relative',
    R_X86_64_DTPMOD64   :'ID of module containing symbol',
    R_X86_64_DTPOFF64   :'Offset in modules TLS block',
    R_X86_64_TPOFF64    :'Offset in initial TLS block',
    R_X86_64_TLSGD      :'32 bit signed PC relative offset to two GOT entries for GD symbol',
    R_X86_64_TLSLD      :'32 bit signed PC relative offset to two GOT entries for LD symbol',
    R_X86_64_DTPOFF32   :'Offset in TLS block',
    R_X86_64_GOTTPOFF   :'32 bit signed PC relative offset to GOT entry for IE symbol',
    R_X86_64_TPOFF32    :'Offset in initial TLS block',
    R_X86_64_GOTOFF64   :'64 bit offset to GOT',
    R_X86_64_GOTPC32    :'32 bit signed pc relative offset to GOT',
    R_X86_64_GOT64      :'64-bit GOT entry offset',
    R_X86_64_GOTPCREL64 :'64-bit PC relative offset to GOT entry',
    R_X86_64_GOTPC64    :'64-bit PC relative offset to GOT',
    R_X86_64_GOTPLT64   :'like GOT64, says PLT entry needed',
    R_X86_64_PLTOFF64   :'64-bit GOT relative offset to PLT entry',
    R_X86_64_SIZE32     :'Size of symbol plus 32-bit addend',
    R_X86_64_SIZE64     :'Size of symbol plus 64-bit addend',
    R_X86_64_GOTPC32_TLSDESC :'GOT offset for TLS descriptor. ',
    R_X86_64_TLSDESC_CALL :'Marker for call through TLS descriptor. ',
    R_X86_64_TLSDESC    :'TLS descriptor. ',
    R_X86_64_IRELATIVE  :'Adjust indirectly by program base',
}

## Define e_flags to 386
SHT_NULL = 0
SHT_PROGBITS = 1
SHT_SYMTAB = 2
SHT_STRTAB = 3
SHT_RELA = 4
SHT_HASH = 5
SHT_DYNAMIC = 6
SHT_NOTE = 7
SHT_NOBITS = 8
SHT_REL = 9
SHT_SHLIB = 10
SHT_DYNSYM = 11
SHT_INIT_ARRAY = 14
SHT_FINI_ARRAY = 15
SHT_PREINIT_ARRAY = 16
SHT_GROUP = 17
SHT_SYMTAB_SHNDX = 18
SHT_LOOS = 0x60000000
SHT_GNU_LIBLIST = 0x6ffffff7
SHT_CHECKSUM = 0x6ffffff8
SHT_LOSUNW = 0x6ffffffa
SHT_GNU_verdef = 0x6ffffffd
SHT_GNU_verneed = 0x6ffffffe
SHT_GNU_versym = 0x6fffffff
SHT_HISUNW = 0x6fffffff
SHT_HIOS = 0x6fffffff
SHT_LOPROC = 0x70000000
SHT_HIPROC = 0x7fffffff
SHT_LOUSER = 0x80000000
SHT_HIUSER = 0x8fffffff

sht_lookup ={y: x for x, y in globals().items() if x.startswith("SHT_")}

sh_type = {
    SHT_NULL:"Section header table entry unused",
    SHT_PROGBITS:"Program data",
    SHT_SYMTAB:"Symbol table",
    SHT_STRTAB:"String table",
    SHT_RELA:"Relocation entries with addends",
    SHT_HASH:"Symbol hash table",
    SHT_DYNAMIC:"Dynamic linking information",
    SHT_NOTE:"Notes",
    SHT_NOBITS:"Program space with no data (bss)",
    SHT_REL:"Relocation entries, no addends",
    SHT_SHLIB:"Reserved",
    SHT_DYNSYM:"Dynamic linker symbol table",
    SHT_INIT_ARRAY:"Array of constructors",
    SHT_FINI_ARRAY:"Array of destructors",
    SHT_PREINIT_ARRAY:"Array of pre-constructors",
    SHT_GROUP:"Section group",
    SHT_SYMTAB_SHNDX:"Extended section indices",
    SHT_LOOS:"Start OS-specific",
    SHT_GNU_LIBLIST:"Prelink library list",
    SHT_CHECKSUM:"Checksum for DSO content.",
    SHT_LOSUNW:"Sun-specific low bound.",
    SHT_GNU_verdef:"Version definition section.",
    SHT_GNU_verneed:"Version needs section.",
    SHT_GNU_versym:"Version symbol table.",
    SHT_HISUNW:"Sun-specific high bound.",
    SHT_HIOS:"End OS-specific type",
    SHT_LOPROC:"Start of processor-specific",
    SHT_HIPROC:"End of processor-specific",
    SHT_LOUSER:"Start of application-specific",
    SHT_HIUSER:"End of application-specific",
}

SHF_WRITE = 1
SHF_ALLOC = 2
SHF_EXECINSTR = 4
SHF_MERGE = 16
SHF_STRINGS = 32
SHF_INFO_LINK = 64
SHF_LINK_ORDER = 128
SHF_OS_NONCONFORMING = 256
SHF_GROUP = 512
SHF_TLS = 1024
SHF_ORDERED = 1073741824
SHF_EXCLUDE = 2147483648

sh_flags = {
    SHF_WRITE:"Writable",
    SHF_ALLOC:"Occupies memory during execution",
    SHF_EXECINSTR:"Executable",
    SHF_MERGE:"Might be merged",
    SHF_STRINGS:"Contains null-terminated strings",
    SHF_INFO_LINK:"`sh_info' contains SHT index",
    SHF_LINK_ORDER:"Preserve order after combining",
    SHF_OS_NONCONFORMING:"Non-standard OS specific",
    SHF_GROUP:"Section is member of a group.",
    SHF_TLS:"Section hold thread-local data.",
    SHF_ORDERED:"Special ordering",
    SHF_EXCLUDE:"Section is excluded",
}

STB_LOCAL = 0
STB_GLOBAL = 1
STB_WEAK = 2
STB_LOOS = 10
STB_HIOS = 12
STB_LOPROC = 13
STB_HIPROC = 15

stb_lookup ={y: x for x, y in globals().items() if x.startswith("STB_")}

st_info_bind = {
    STB_LOCAL:"Local symbol",
    STB_GLOBAL:"Global symbol",
    STB_WEAK:"Weak symbol",
    STB_LOOS:"Start of OS-specific",
    STB_HIOS:"End of OS-specific",
    STB_LOPROC:"Start of processor-specific",
    STB_HIPROC:"End of processor-specific",
}

STT_NOTYPE = 0
STT_OBJECT = 1
STT_FUNC = 2
STT_SECTION = 3
STT_FILE = 4
STT_COMMON = 5
STT_TLS = 6
STT_LOOS = 10
STT_MDOS = 11  # there's only one that isn't HI or LO...
STT_HIOS = 12
STT_LOPROC = 13
STT_MDPROC = 14
STT_HIPROC = 15

STT_GNU_IFUNC = 10

stt_lookup ={y: x for x, y in globals().items() if x.startswith("STT_")}

st_info_type = {
    STT_NOTYPE:"Symbol type is unspecified",
    STT_OBJECT:"Symbol is a data object",
    STT_FUNC:"Symbol is a code object",
    STT_SECTION:"Symbol associated with a section",
    STT_FILE:"Symbol's name is file name",
    STT_COMMON:"Symbol is a common data object",
    STT_TLS:"Symbol is thread-local data",
    STT_LOOS:"Start of OS-specific",
    STT_MDOS:"Middle of OS-specific",
    STT_HIOS:"End of OS-specific",
    STT_LOPROC:"Start of processor-specific",
    STT_MDPROC:"Middle of processor-specific",
    STT_HIPROC:"End of processor-specific",
}

STV_DEFAULT     = 0
STV_INTERNAL    = 1
STV_HIDDEN      = 2
STV_PROTECTED   = 3

stv_lookup ={y: x for x, y in globals().items() if x.startswith("STV_")}

st_other_visibility = {
    STV_DEFAULT:"Symbol visibility specified by binding type",
    STV_INTERNAL:"Symbol visibility is reserved",
    STV_HIDDEN:"Symbol is not visible to other objects",
    STV_PROTECTED:"Symbol is visible by other objects, but cannot be preempted"
}

SHN_UNDEF = 0
SHN_LORESERVE = SHN_LOPROC = SHN_BEFORE = 0xff00
SHN_AFTER = 0xff01
SHN_HIPROC = 0xff1f
SHN_ABS = 0xfff1
SHN_COMMON = 0xfff2
SHN_HIRESERVE = 0xffff

shn_special_section_indices = {
    SHN_UNDEF: "Undefined/Missing/Irrelevant Section Index",
    SHN_LORESERVE: "Lower boundary of reserved values",
    SHN_AFTER: "Marker for initial section ordering with SHF_LINK_ORDER and SHF_ORDER section flags",
    SHN_HIPROC: "Marker for final section ordering with SHF_LINK_ORDER and SHF_ORDER section flags",
    SHN_ABS: "Relative Symbols are absolute references",
    SHN_COMMON: "Relative symbols are common symbols (also called tentative symbols)",
    SHN_HIRESERVE: "Upper boundary of reserved values",
}

DT_NULL     = 0
DT_NEEDED   = 1
DT_PLTRELSZ = 2
DT_PLTGOT   = 3
DT_HASH     = 4
DT_STRTAB   = 5
DT_SYMTAB   = 6
DT_RELA     = 7
DT_RELASZ   = 8
DT_RELAENT  = 9
DT_STRSZ    = 10
DT_SYMENT   = 11
DT_INIT     = 12
DT_FINI     = 13
DT_SONAME   = 14
DT_RPATH    = 15
DT_SYMBOLIC = 16
DT_REL      = 17
DT_RELSZ    = 18
DT_RELENT   = 19
DT_PLTREL   = 20
DT_DEBUG    = 21
DT_TEXTREL  = 22
DT_JMPREL   = 23
DT_BIND_NOW = 24
DT_INIT_ARRAY   = 25
DT_FINI_ARRAY   = 26
DT_INIT_ARRAYSZ = 27
DT_FINI_ARRAYSZ = 28
DT_RUNPATH  = 29
DT_FLAGS    = 30
DT_ENCODING = 32
DT_PREINIT_ARRAY = 32
DT_PREINIT_ARRAYSZ = 33
DT_NUM      = 34
DT_GNU_PRELINKED    = 0x6ffffdf5
DT_GNU_CONFLICTSZ   = 0x6ffffdf6
DT_GNU_LIBLISTSZ    = 0x6ffffdf7
DT_CHECKSUM         = 0x6ffffdf8
DT_PLTPADSZ         = 0x6ffffdf9
DT_MOVEENT          = 0x6ffffdfa
DT_MOVESZ           = 0x6ffffdfb
DT_FEATURE_1        = 0x6ffffdfc
DT_POSFLAG_1        = 0x6ffffdfd
DT_SYMINSZ          = 0x6ffffdfe
DT_SYMINENT         = 0x6ffffdff
DT_GNU_HASH         = 0x6ffffef5
DT_TLSDESC_PLT      = 0x6ffffef6
DT_TLSDESC_GOT      = 0x6ffffef7
DT_GNU_CONFLICT     = 0x6ffffef8
DT_GNU_LIBLIST      = 0x6ffffef9
DT_CONFIG           = 0x6ffffefa
DT_DEPAUDIT         = 0x6ffffefb
DT_AUDIT            = 0x6ffffefc
DT_PLTPAD           = 0x6ffffefd
DT_MOVETAB          = 0x6ffffefe
DT_SYMINFO          = 0x6ffffeff
DT_VERSYM           = 0x6ffffff0
DT_RELACOUNT        = 0x6ffffff9
DT_RELCOUNT         = 0x6ffffffa
DT_FLAGS_1          = 0x6ffffffb
DT_VERDEF           = 0x6ffffffc
DT_VERDEFNUM        = 0x6ffffffd
DT_VERNEED          = 0x6ffffffe
DT_VERNEEDNUM       = 0x6fffffff
DT_AUXILIARY        = 0x7ffffffd
DT_FILTER           = 0x7fffffff
DT_LOOS             = 0x6000000d
DT_HIOS             = 0x6ffff000
DT_LOPROC           = 0x70000000
DT_HIPROC           = 0x7fffffff
#DT_PROCNUM  = DT_MIPS_NUM

dt_names = { v:k for k,v in globals().items() if k.startswith('DT_')}

dt_types = {
    DT_NULL     : "Marks end of dynamic section ",
    DT_NEEDED   : "Name of needed library ",
    DT_PLTRELSZ : "Size in bytes of PLT relocs ",
    DT_PLTGOT   : "Processor defined value ",
    DT_HASH     : "Address of symbol hash table ",
    DT_STRTAB   : "Address of string table ",
    DT_SYMTAB   : "Address of symbol table ",
    DT_RELA     : "Address of Rela relocs ",
    DT_RELASZ   : "Total size of Rela relocs ",
    DT_RELAENT  : "Size of one Rela reloc ",
    DT_STRSZ    : "Size of string table ",
    DT_SYMENT   : "Size of one symbol table entry ",
    DT_INIT     : "Address of init function ",
    DT_FINI     : "Address of termination function ",
    DT_SONAME   : "Name of shared object ",
    DT_RPATH    : "Library search path (deprecated) ",
    DT_SYMBOLIC : "Start symbol search here ",
    DT_REL      : "Address of Rel relocs ",
    DT_RELSZ    : "Total size of Rel relocs ",
    DT_RELENT   : "Size of one Rel reloc ",
    DT_PLTREL   : "Type of reloc in PLT ",
    DT_DEBUG    : "For debugging; unspecified ",
    DT_TEXTREL  : "Reloc might modify .text ",
    DT_JMPREL   : "Address of PLT relocs ",
    DT_BIND_NOW : "Process relocations of object ",
    DT_INIT_ARRAY   : "Array with addresses of init fct ",
    DT_FINI_ARRAY   : "Array with addresses of fini fct ",
    DT_INIT_ARRAYSZ : "Size in bytes of DT_INIT_ARRAY ",
    DT_FINI_ARRAYSZ : "Size in bytes of DT_FINI_ARRAY ",
    DT_RUNPATH  : "Library search path ",
    DT_FLAGS    : "Flags for the object being loaded ",
    DT_FLAGS_1  : "Flags (auxiliary) for the object being loaded ",
    DT_ENCODING : "Start of encoded range ",
    DT_PREINIT_ARRAY : "Array with addresses of preinit fct",
    DT_PREINIT_ARRAYSZ : "size in bytes of DT_PREINIT_ARRAY ",
    DT_NUM      : "Number used ",
    DT_LOOS     : "Start of OS-specific ",
    DT_HIOS     : "End of OS-specific ",
    DT_LOPROC   : "Start of processor-specific ",
    DT_HIPROC   : "End of processor-specific ",
    DT_VERDEF   : "Version Definition Offset ",
    DT_VERDEFNUM: "Version Definition Structure Count ",
    DT_VERNEED  : "Required Version Offset ",
    DT_VERNEEDNUM: "Required Version Structure Count ",
    DT_VERSYM   : "Address of Version Section"
    #DT_PROCNUM  : "Most used by any processor ",
}

# which Dynamic Types require rebasing
dt_rebase = (
        DT_INIT, 
        DT_FINI, 
        DT_INIT_ARRAY, 
        DT_FINI_ARRAY, 
        DT_GNU_HASH,
        DT_STRTAB,
        DT_SYMTAB,
        DT_PLTGOT,
        DT_JMPREL,
        DT_REL,
        DT_VERNEED,
)

DF_ORIGIN =         0x00000001
DF_SYMBOLIC =       0x00000002
DF_TEXTREL =        0x00000004
DF_BIND_NOW =       0x00000008
DF_STATIC_TLS =     0x00000010

df_names = { v:k for k,v in globals().items() if k.startswith('DF_')}

df_types = {
    DF_ORIGIN: 'Object may use DF_ORIGIN',
    DF_SYMBOLIC: 'Symbol resolutions starts here',
    DF_TEXTREL: 'Object contains text relocations',
    DF_BIND_NOW: 'No lazy binding for this object',
    DF_STATIC_TLS: 'Module uses the static TLS model',
}

PT_NULL     = 0
PT_LOAD     = 1
PT_DYNAMIC  = 2
PT_INTERP   = 3
PT_NOTE     = 4
PT_SHLIB    = 5
PT_PHDR     = 6
PT_TLS      = 7
PT_NUM      = 8
PT_LOOS     = 0x60000000
PT_GNU_EH_FRAME  = 0x6474e550
PT_GNU_STACK  = 0x6474e551
PT_GNU_RELRO  = 0x6474e552
PT_LOSUNW   = 0x6ffffffa
PT_SUNWBSS  = 0x6ffffffa
PT_SUNWSTACK = 0x6ffffffb
PT_HISUNW =  0x6fffffff
PT_HIOS   =  0x6fffffff
PT_LOPROC =  0x70000000
PT_HIPROC =  0x7fffffff

ph_types = {
    PT_NULL:"Program header table entry unused",
    PT_LOAD:"Loadable program segment",
    PT_DYNAMIC:"Dynamic linking information",
    PT_INTERP:"Program interpreter",
    PT_NOTE:"Auxiliary information",
    PT_SHLIB:"Reserved",
    PT_PHDR:"Entry for header table itself",
    PT_TLS:"Thread-local storage segment",
    PT_NUM:"Number of defined types",
    PT_LOOS:"Start of OS-specific",
    PT_GNU_EH_FRAME:"GCC .eh_frame_hdr segment",
    PT_GNU_STACK:"Indicates stack executability",
    PT_GNU_RELRO:"Read-only after relocation",
    PT_SUNWBSS:"Sun Specific segment",
    PT_SUNWSTACK:"Stack segment",
    PT_HIOS:"End of OS-specific",
    PT_LOPROC:"Start of processor-specific",
    PT_HIPROC:"End of processor-specific",
}

# GNU .note.ABI-tag
osnotes = {
    0:'linux',
    1:'gnu',
    2:'solaris',
    3:'freebsd',
}
